@@ -19,7 +19,6 @@
  */
 #include "jstreamsconfig.h"
 #include "indexer.h"
-#include "filtermanager.h"
 
 int
 main(int argc, char **argv) {
@@ -27,9 +26,9 @@ main(int argc, char **argv) {
         printf("Usage: %s [indexdir] [dir-to-index]\n", argv[0]);
         return -1;
     }
-    
-    FilterManager filtermanager;
-    Indexer indexer(argv[1], &filtermanager);
+
+    IndexerConfiguration ic;
+    Indexer indexer(argv[1], ic);
     indexer.index(argv[2]);
     return 0;
 }
