@@ -46,7 +46,7 @@ AsyncSocketClient::splitResponse() const {
     vector<string> response;
     const char* p = socket.getResponse().c_str();
     string line;
-    
+
     while (true)
     {
         if ((*p != '\n') && (*p != '\0'))
@@ -56,13 +56,13 @@ AsyncSocketClient::splitResponse() const {
             response.push_back (line);
             line.clear();
         }
-        
+
         p++;
-        
+
         if (*p == '\0')
             break;
     }
-    
+
     return response;
 }
 bool
@@ -110,7 +110,7 @@ AsyncSocketClient::handleQueryResponse() {
             const char* d = strchr(s, '/');
             if (d && d < v) break;
             string n(s, v-s);
-            h.properties.insert(make_pair(n,v+1));
+            h.properties.insert(make_pair<const string, string>(n,v+1));
             ++i;
         }
         hits.hits.push_back(h);
@@ -129,7 +129,7 @@ AsyncSocketClient::handleGetIndexedDirectoriesResponse() {
     if (socket.getStatus() == AsyncSocket::Error) {
         return;
     }
-    
+
     indexedDirs = splitResponse();
 }
 bool
@@ -148,7 +148,7 @@ AsyncSocketClient::handleGetDaemonStatusResponse() {
     vector<string> response = splitResponse();
     for (uint i=0; i<response.size(); ++i) {
         string s = response[i];
-        uint p = s.find(":");
+        string::size_type p = s.find(":");
         if (p == string::npos) {
             daemonStatus.clear();
             daemonStatus["error"] = "Communication error.";
