@@ -29,16 +29,6 @@ class ClientInterface {
 protected:
     bool active;
 public:
-/*    class Hit {
-    public:
-        std::string uri;
-        double score;
-        std::string fragment;
-        std::string mimetype;
-        int64_t size;
-        time_t mtime;
-        std::map<std::string, std::string> properties;
-    };*/
     class Hits {
     public:
         std::vector<jstreams::IndexedDocument> hits;
@@ -47,21 +37,26 @@ public:
 
     ClientInterface() :active(true) {}
     virtual ~ClientInterface() {}
-    virtual int countHits(const std::string& query) = 0;
-    virtual Hits getHits(const std::string& query, int max, int offset) = 0;
+    virtual int32_t countHits(const std::string& query) = 0;
+    virtual Hits getHits(const std::string& query, uint32_t max, uint32_t offset) = 0;
     virtual std::map<std::string, std::string> getStatus() = 0;
     virtual std::string stopDaemon() = 0;
     virtual std::string startIndexing() = 0;
     virtual std::string stopIndexing() = 0;
     virtual std::set<std::string> getIndexedDirectories() = 0;
     virtual std::string setIndexedDirectories(std::set<std::string> d) = 0;
-    virtual std::multimap<int, std::string> getFilteringRules() = 0;
-    virtual void setFilteringRules(const std::multimap<int, std::string>& rules)
-        = 0;
+    virtual void setFilters(const std::vector<std::pair<bool,std::string> >& rules) = 0;
+    virtual std::vector<std::pair<bool,std::string> > getFilters() = 0;
     virtual std::set<std::string> getIndexedFiles() = 0;
     bool isActive() { return active; }
     virtual std::vector<std::string> getBackEnds() = 0;
     virtual void indexFile(const std::string& path, uint64_t mtime, const std::vector<char>& content) = 0;
+
+    virtual std::vector<std::string> getFieldNames() = 0;
+    virtual std::vector<std::pair<std::string, uint32_t> > getHistogram(const std::string& query, const std::string& field, const std::string& labeltype) = 0;
+
+    virtual int32_t countKeywords(const std::string& keywordprefix, const std::vector<std::string>& fieldnames) = 0;
+    virtual std::vector<std::string> getKeywords(const std::string& keywordmatch, const std::vector<std::string>& fieldnames, uint32_t max, uint32_t offset) = 0;
 };
 
 #endif
