@@ -23,6 +23,7 @@
 #include "combinedindexmanager.h"
 
 #include "indexscheduler.h"
+#include "indexerconfiguration.h"
 
 #if defined (HAVE_INOTIFY)
 #include "inotifylistener.h"
@@ -31,7 +32,6 @@
 #include "eventlistener.h"
 #endif
 #include "eventlistenerqueue.h"
-#include "filtermanager.h"
 #include "strigilogging.h"
 
 #ifdef HAVE_DBUS
@@ -152,12 +152,12 @@ main(int argc, char** argv) {
     DaemonConfigurator config (conffile);
 
     // init filter manager
-    FilterManager filterManager;
-    config.loadFilteringRules (&filterManager);
+    IndexerConfiguration ic;
+    config.loadFilteringRules(ic);
     STRIGI_LOG_DEBUG("strigi.daemon", "filter manager initialized")
-    
+
     IndexScheduler scheduler;
-    scheduler.setFilterManager (&filterManager);
+    scheduler.setIndexerConfiguration(&ic);
 
     if (!initializeDir(lucenedir)) {
         STRIGI_LOG_FATAL ("strigi.daemon",
@@ -189,7 +189,7 @@ main(int argc, char** argv) {
     for (i = rors.begin(); i != rors.end(); ++i) {
         index->addReadonlyIndex(i->a_indexdir, i->a_type);
     }
-    
+
     scheduler.setIndexManager(index);
     scheduler.setIndexedDirectories(dirs);
 
@@ -203,7 +203,7 @@ main(int argc, char** argv) {
     Interface interface(*index, scheduler);
 
     EventListener* listener = NULL;
-    
+
 #if defined (HAVE_INOTIFY)
     // listen for requests
     listener = new InotifyListener(dirs);
@@ -218,7 +218,7 @@ main(int argc, char** argv) {
     // configure & start inotfy's watcher thread
     if (listener  && listener->init()) {
         listener->setEventListenerQueue (&listenerEventQueue);
-        listener->setFilterManager (&filterManager);
+        listener->setIndexerConfiguration(&ic);
         listener->setIndexReader (index->getIndexReader());
         listener->setPollingInterval (config.getPollingInterval());
         // do not start scanning until execution is in the thread!
@@ -228,12 +228,9 @@ main(int argc, char** argv) {
     interface.setEventListener (listener);
 //    threads.push_back(listener);
 
-    interface.setFilterManager (&filterManager);
-
 #ifdef HAVE_DBUS
     DBusServer dbusserver(&interface);
     if (config.useDBus()) {
-//        threads.push_back(&dbusserver);
         dbusserver.start();
     }
 #endif
@@ -243,22 +240,22 @@ main(int argc, char** argv) {
 
     server.listen();
     StrigiThread::stopThreads();
-   
+
     //save indexed dirs
     dirs = scheduler.getIndexedDirectories();
     config.setIndexedDirectories (dirs);
-  
+
     //save the pollingtime
     if (listener) {
         config.setPollingInterval (listener->getPollingInterval());
     }
- 
+
     //save filtering rules
-    config.saveFilteringRules (&filterManager);
-    
+    config.saveFilteringRules(scheduler.getIndexerConfiguration().getFilters());
+
     //save the updated xml configuration file
     config.save();
-    
+
     // close the indexmanager
     delete index;
 
