@@ -73,7 +73,7 @@ DBusMessageReader::operator>>(int64_t& s) {
     return *this;
 }
 DBusMessageReader&
-DBusMessageReader::operator>>(std::string& s) {
+DBusMessageReader::operator>>(string& s) {
     if (!isOk()) return *this;
     if (DBUS_TYPE_STRING != dbus_message_iter_get_arg_type(&it)) {
         close();
@@ -96,18 +96,41 @@ DBusMessageReader::operator>>(set<string>& s) {
     }
 
     DBusMessageIter sub;
-    dbus_message_iter_recurse(&it, &sub);
     const char* value;
-    do {
+    dbus_message_iter_recurse(&it, &sub);
+    while (dbus_message_iter_get_arg_type(&sub) == DBUS_TYPE_STRING) {
         dbus_message_iter_get_basic(&sub, &value);
         s.insert(value);
-    } while(dbus_message_iter_next(&sub));
+        dbus_message_iter_next(&sub);
+    }
     dbus_message_iter_next(&it);
-   
+
     return *this;
 }
 DBusMessageReader&
-DBusMessageReader::operator>>(std::vector<char>& s) {
+DBusMessageReader::operator>>(vector<string>& s) {
+    s.clear();
+    if (!isOk()) return *this;
+    if (DBUS_TYPE_ARRAY != dbus_message_iter_get_arg_type(&it)
+        || DBUS_TYPE_STRING != dbus_message_iter_get_element_type(&it)) {
+        close();
+        return *this;
+    }
+
+    DBusMessageIter sub;
+    const char* value;
+    dbus_message_iter_recurse(&it, &sub);
+    while (dbus_message_iter_get_arg_type(&sub) == DBUS_TYPE_STRING) {
+        dbus_message_iter_get_basic(&sub, &value);
+        s.push_back(value);
+        dbus_message_iter_next(&sub);
+    }
+    dbus_message_iter_next(&it);
+
+    return *this;
+}
+DBusMessageReader&
+DBusMessageReader::operator>>(vector<char>& s) {
     if (!isOk()) return *this;
     if (DBUS_TYPE_ARRAY != dbus_message_iter_get_arg_type(&it)
         || DBUS_TYPE_BYTE != dbus_message_iter_get_element_type(&it)) {
@@ -126,25 +149,66 @@ DBusMessageReader::operator>>(std::vector<char>& s) {
     return *this;
 }
 DBusMessageReader&
-DBusMessageReader::operator>>(std::multimap<int, std::string>& m) {
+DBusMessageReader::operator>>(multimap<int, string>& m) {
     if (!isOk()) return *this;
-    if (DBUS_TYPE_ARRAY != dbus_message_iter_get_arg_type(&it)
-        || DBUS_TYPE_STRUCT != dbus_message_iter_get_element_type(&it)) {
-        close();
-        return *this;
-    }
     DBusMessageIter sub;
     DBusMessageIter ssub;
-    dbus_message_iter_recurse(&it, &sub);
     int32_t n;
     const char* value;
-    do {
-        // this probably does not work without opening each struct for reading
-        dbus_message_iter_recurse(&sub, &ssub);
-        dbus_message_iter_get_basic(&sub, &n);
-        dbus_message_iter_get_basic(&sub, &value);
-        m.insert(make_pair(n,value));
-    } while(dbus_message_iter_next(&sub));
+    if (dbus_message_iter_get_arg_type(&it) == DBUS_TYPE_ARRAY) {
+        dbus_message_iter_recurse(&it, &sub);
+        while (dbus_message_iter_get_arg_type(&sub) == DBUS_TYPE_STRUCT) {
+            dbus_message_iter_recurse(&sub, &ssub);
+            if (dbus_message_iter_get_arg_type(&ssub) != DBUS_TYPE_INT32) {
+                close();
+                return *this;
+            }
+            dbus_message_iter_get_basic(&ssub, &n);
+            dbus_message_iter_next(&ssub);
+            if (dbus_message_iter_get_arg_type(&ssub) != DBUS_TYPE_STRING) {
+                close();
+                return *this;
+            }
+            dbus_message_iter_get_basic(&ssub, &value);
+            m.insert(make_pair<int,string>(n,value));
+            if (!dbus_message_iter_has_next(&sub)) {
+                break;
+            }
+            dbus_message_iter_next(&sub);
+        }
+    }
+    dbus_message_iter_next(&it);
+    return *this;
+}
+DBusMessageReader&
+DBusMessageReader::operator>>(vector<pair<bool, string> >& m) {
+    if (!isOk()) return *this;
+    DBusMessageIter sub;
+    DBusMessageIter ssub;
+    bool n;
+    const char* value;
+    if (dbus_message_iter_get_arg_type(&it) == DBUS_TYPE_ARRAY) {
+        dbus_message_iter_recurse(&it, &sub);
+        while (dbus_message_iter_get_arg_type(&sub) == DBUS_TYPE_STRUCT) {
+            dbus_message_iter_recurse(&sub, &ssub);
+            if (dbus_message_iter_get_arg_type(&ssub) != DBUS_TYPE_BOOLEAN) {
+                close();
+                return *this;
+            }
+            dbus_message_iter_get_basic(&ssub, &n);
+            dbus_message_iter_next(&ssub);
+            if (dbus_message_iter_get_arg_type(&ssub) != DBUS_TYPE_STRING) {
+                close();
+                return *this;
+            }
+            dbus_message_iter_get_basic(&ssub, &value);
+            m.push_back(make_pair<bool,string>(n,value));
+            if (!dbus_message_iter_has_next(&sub)) {
+                break;
+            }
+            dbus_message_iter_next(&sub);
+        }
+    }
     dbus_message_iter_next(&it);
     return *this;
 }
