@@ -17,14 +17,17 @@ my $classname;
 my %typemapping = (
 	"void" => "ignore",
 	"std::string" => "s",
-	"int" => "i",
+	"int32_t" => "i",
+	"uint32_t" => "u",
 	"bool" => "b",
 	"std::vector<std::string>" => "as",
 	"std::set<std::string>" => "as",
-	"Hits" => "a(sdsssxta(ss))",
+	"Hits" => "a(sdsssxxa{sas})",
 	"std::map<std::string, std::string>" => "a{ss}",
 	"std::vector<char>" => "ay",
 	"std::multimap<int, std::string>" => "a(is)",
+	"std::vector<std::pair<bool,std::string> >" => "a(bs)",
+	"std::vector<std::pair<std::string, uint32_t> >" => "a(su)",
 	"uint64_t" => "t"
 );
 
