@@ -25,11 +25,10 @@
 #include "strigithread.h"
 
 class EventListenerQueue;
-class FilterManager;
 
-namespace jstreams
-{
+namespace jstreams {
     class IndexReader;
+    class IndexerConfiguration;
 }
 
 /*!
@@ -41,22 +40,22 @@ class EventListener : public StrigiThread {
 public:
     explicit EventListener(const char* name) :StrigiThread(name) {
         m_pEventQueue = NULL;
-        m_pFilterManager = NULL;
+        m_pindexerconfiguration = NULL;
         m_pIndexReader = NULL;
         m_pollingInterval = 180;
     }
 
     virtual ~EventListener() {};
 
-    virtual bool init() = 0;
+    virtual bool init() { return true; }
     virtual bool addWatch (const std::string& path) = 0;
     virtual void addWatches (const std::set<std::string>& watches) = 0;
     virtual void setIndexedDirectories (const std::set<std::string>& dirs) = 0;
     void setEventListenerQueue (EventListenerQueue* eventQueue) {
         m_pEventQueue = eventQueue;
     }
-    void setFilterManager (FilterManager* filterManager) {
-        m_pFilterManager = filterManager;
+    void setIndexerConfiguration(jstreams::IndexerConfiguration* ic) {
+        m_pindexerconfiguration = ic;
     }
     void setIndexReader (jstreams::IndexReader* ireader) {
         m_pIndexReader = ireader;
@@ -64,9 +63,9 @@ public:
     unsigned int getPollingInterval() {
         return m_pollingInterval;
     }
-    /*! 
+    /*!
     * configure the polling interval. The time elapsed between each polling
-    * operation (expressed in seconds) 
+    * operation (expressed in seconds)
     */
     void setPollingInterval(unsigned int value) {
         m_pollingInterval = value;
@@ -74,7 +73,7 @@ public:
 
 protected:
     EventListenerQueue* m_pEventQueue;
-    FilterManager* m_pFilterManager;
+    jstreams::IndexerConfiguration* m_pindexerconfiguration;
     jstreams::IndexReader* m_pIndexReader;
     unsigned int m_pollingInterval;//!< pause time between each polling operation
 };
