@@ -25,7 +25,7 @@
 #include "jstreamsconfig.h"
 #include "event.h"
 #include "eventlistenerqueue.h"
-#include "filtermanager.h"
+#include "indexerconfiguration.h"
 
 #include "filelister.h"
 #include "streamindexer.h"
@@ -42,17 +42,15 @@ IndexScheduler* sched;
 IndexScheduler::IndexScheduler() :StrigiThread("IndexScheduler") {
     sched = this;
     m_listenerEventQueue = NULL;
-    m_filterManager = NULL;
 }
 IndexScheduler::~IndexScheduler() {
 }
-bool
+void
 IndexScheduler::addFileCallback(const char* path, uint dirlen, uint len,
         time_t mtime) {
-    if (sched->getState() != Working) return false;
     // only read files that do not start with '.'
-    if (path[dirlen] == '.') return true;
-   
+    if (path[dirlen] == '.') return;
+
     std::string filepath(path, len);
 
     map<string, time_t>::iterator i = sched->dbfiles.find(filepath);
@@ -63,7 +61,6 @@ IndexScheduler::addFileCallback(const char* path, uint dirlen, uint len,
     } else {
         sched->dbfiles.erase(i);
     }
-    return true;
 }
 std::string
 IndexScheduler::getStateString() {
@@ -97,7 +94,7 @@ IndexScheduler::run(void*) {
         else if (getState() == Idling) {
             if (m_listenerEventQueue == NULL)
                 return 0;
-           
+
             vector <Event*> events = m_listenerEventQueue->getEvents();
             if (events.size() > 0) {
                 setState(Working);
@@ -106,7 +103,7 @@ IndexScheduler::run(void*) {
             }
         }
     }
-    
+
     STRIGI_LOG_DEBUG ("strigi.IndexScheduler.run", string("exit state: ") + getStringState());
     return 0;
 }
@@ -114,28 +111,29 @@ void
 IndexScheduler::index() {
     IndexReader* reader = indexmanager->getIndexReader();
     IndexWriter* writer = indexmanager->getIndexWriter();
-    StreamIndexer* streamindexer = new StreamIndexer(writer);
+    StreamIndexer* streamindexer = new StreamIndexer(*writer,
+        *m_indexerconfiguration);
 
     if (dbfiles.size() == 0 && toindex.size() == 0) {
         // retrieve the list of real files currently in the database
         dbfiles = reader->getFiles(0);
-       
+
         char buff [20];
         snprintf(buff, 20* sizeof (char), "%i", dbfiles.size());
         STRIGI_LOG_DEBUG ("strigi.IndexScheduler", string(buff) + " real files in the database")
 
         // first loop through all files
-        FileLister lister (m_filterManager);
+        FileLister lister (*m_indexerconfiguration);
         lister.setFileCallbackFunction(&addFileCallback);
         STRIGI_LOG_DEBUG ("strigi.IndexScheduler", "going to index")
         set<string>::const_iterator i;
         for (i = dirstoindex.begin(); i != dirstoindex.end(); ++i) {
             lister.listFiles(i->c_str());
         }
-       
+
         snprintf(buff, 20* sizeof (char), "%i", dbfiles.size());
         STRIGI_LOG_DEBUG ("strigi.IndexScheduler", string(buff) + " files to remove")
-       
+
         snprintf(buff, 20* sizeof (char), "%i", toindex.size());
         STRIGI_LOG_DEBUG ("strigi.IndexScheduler", string(buff) + " files to add or update")
     }
@@ -169,18 +167,19 @@ void
 IndexScheduler::processListenerEvents(vector<Event*>& events) {
     IndexReader* reader = indexmanager->getIndexReader();
     IndexWriter* writer = indexmanager->getIndexWriter();
-    StreamIndexer* streamindexer = new StreamIndexer(writer);
-   
+    IndexerConfiguration ic;
+    StreamIndexer* streamindexer = new StreamIndexer(*writer, ic);
+
     vector<string> toDelete;
-   
+
     STRIGI_LOG_DEBUG ("strigi.IndexScheduler", "processing listener's events")
 
     for(vector<Event*>::iterator iter = events.begin(); iter != events.end(); iter++)
     {
         Event* event = *iter;
-        
+
         STRIGI_LOG_DEBUG ("strigi.IndexScheduler", "event infos: " + event->toString())
-        
+
         switch (event->getType())
         {
             case Event::CREATED:
@@ -202,7 +201,7 @@ IndexScheduler::processListenerEvents(vector<Event*>& events) {
                 toDelete.push_back (event->getPath());
                 break;
         }
-       
+
         delete event;
     }
     writer->deleteEntries(toDelete);
@@ -216,10 +215,10 @@ IndexScheduler::processListenerEvents(vector<Event*>& events) {
         }
         toindex.erase(it++);
     }
-   
+
     writer->commit();
     writer->optimize();
-   
+
     delete streamindexer;
 }
 
