@@ -24,37 +24,39 @@
 #include "indexwriter.h"
 #include "indexscheduler.h"
 #include "eventlistener.h"
-#include "filtermanager.h"
 #include "streamindexer.h"
+#include "indexable.h"
+#include "indexerconfiguration.h"
 #include "stringreader.h"
 #include "query.h"
+#include "indexerconfiguration.h"
 #include <sstream>
 #include <vector>
+#include <sys/types.h>
+#include <signal.h>
+#include <unistd.h>
 using namespace std;
 using namespace jstreams;
 
 Interface::Interface(CombinedIndexManager& m, IndexScheduler& s)
         :manager(m), scheduler(s) {
     eventListener = NULL;
-    filterManager = NULL;
 }
 void
 Interface::setEventListener (EventListener* eListener) {
     eventListener = eListener;
 }
-void
-Interface::setFilterManager (FilterManager* fManager) {
-    filterManager = fManager;
-}
 int
 Interface::countHits(const string& query) {
-    Query q(query, -1, 0);
+    QueryParser parser;
+    Query q = parser.buildQuery(query, -1, 0);
     int count = manager.getIndexReader()->countHits(q);
     return count;
 }
 ClientInterface::Hits
-Interface::getHits(const string& query, int max, int off) {
-    Query q(query, max, off);
+Interface::getHits(const string& query, uint32_t max, uint32_t off) {
+    QueryParser parser;
+    Query q = parser.buildQuery(query, max, off);
     Hits hits;
     hits.hits = manager.getIndexReader()->query(q);
     // highlight the hits in the results
@@ -64,7 +66,7 @@ Interface::getHits(const string& query, int max, int off) {
     }
     return hits;
 }
-std::vector<std::string>
+vector<string>
 Interface::getBackEnds() {
     return manager.getBackEnds();
 }
@@ -90,7 +92,9 @@ Interface::getStatus() {
 string
 Interface::stopDaemon() {
     active = false;
-    scheduler.stop();
+    // signal to all threads to quit. Do not use raise() here, because it will
+    // cause a hang
+    kill(getpid(), SIGINT);
     return "";
 }
 string
@@ -115,40 +119,55 @@ Interface::setIndexedDirectories(set<string> dirs) {
     scheduler.setIndexedDirectories(dirs);
     return "";
 }
-multimap<int,string>
-Interface::getFilteringRules() {
-    if (filterManager != NULL)
-        return filterManager->getFilteringRules();
-    else
-    {
-        multimap<int,string> empty;
-        return empty;
-    }
-}
 void
-Interface::setFilteringRules(const multimap<int,string>& rules) {
-    if (filterManager != NULL)
-        filterManager->setFilteringRules (rules);
+Interface::setFilters(const vector<pair<bool,string> >& rules) {
+    scheduler.getIndexerConfiguration().setFilters(rules);
+}
+vector<pair<bool,string> >
+Interface::getFilters() {
+    return scheduler.getIndexerConfiguration().getFilters();
 }
 set<string>
 Interface::getIndexedFiles() {
-    map <string, time_t> indexedfiles = manager.getIndexReader()->getFiles(0);
-    set <string> r;
-    
+    map<string, time_t> indexedfiles = manager.getIndexReader()->getFiles(0);
+    set<string> r;
+
     for (map<string, time_t>::iterator iter = indexedfiles.begin(); iter != indexedfiles.end(); iter++)
         r.insert (iter->first);
-    
+
     return r;
 }
 void
-Interface::indexFile(const std::string &path, uint64_t mtime,
-        const std::vector<char>& content) {
+Interface::indexFile(const string &path, uint64_t mtime,
+        const vector<char>& content) {
     // TODO if the file is already there, remove it first
     IndexWriter* writer = manager.getIndexWriter();
     vector<string> paths;
     paths.push_back(path);
     writer->deleteEntries(paths);
-    StreamIndexer streamindexer(writer);
+    IndexerConfiguration ic;
+    StreamIndexer streamindexer(*writer, ic);
     StringReader<char> sr(&content[0], content.size(), false);
-    char r = streamindexer.analyze(path, mtime, &sr, 0);
+    Indexable idx(path, mtime, *writer, streamindexer);
+    idx.index(sr);
+}
+vector<string>
+Interface::getFieldNames() {
+    return manager.getIndexReader()->getFieldNames();
+}
+vector<pair<string, uint32_t> >
+Interface::getHistogram(const string& query, const string& field,
+        const string& labeltype) {
+    return manager.getIndexReader()->getHistogram(query, field, labeltype);
+}
+int32_t
+Interface::countKeywords(const string& keywordmatch,
+        const vector<string>& fieldnames) {
+    return 0;
+}
+vector<string>
+Interface::getKeywords(const string& keywordmatch,
+        const vector<string>& fieldnames,
+        uint32_t max, uint32_t offset) {
+    return vector<string>();
 }
