@@ -25,7 +25,6 @@
 class CombinedIndexManager;
 class IndexScheduler;
 class EventListener;
-class FilterManager;
 
 /**
  * This class exposes the daemon functionality to the clients and should be
@@ -38,12 +37,11 @@ private:
     CombinedIndexManager& manager;
     IndexScheduler& scheduler;
     EventListener* eventListener;
-    FilterManager* filterManager;
 
 public:
     Interface(CombinedIndexManager& m, IndexScheduler& s);
     int countHits(const std::string& query);
-    Hits getHits(const std::string& query, int max, int offset);
+    Hits getHits(const std::string& query, uint32_t max, uint32_t offset);
     std::map<std::string, std::string> getStatus();
     std::string stopDaemon();
     std::string startIndexing();
@@ -52,12 +50,21 @@ public:
     std::string setIndexedDirectories(std::set<std::string>);
     std::multimap<int, std::string> getFilteringRules();
     void setFilteringRules(const std::multimap<int, std::string>&);
-    void setEventListener(EventListener* eListener);
-    void setFilterManager(FilterManager* fManager);
+    void setFilters(const std::vector<std::pair<bool,std::string> >& rules);
+    std::vector<std::pair<bool,std::string> > getFilters();
     std::set<std::string> getIndexedFiles();
     void indexFile(const std::string &path, uint64_t mtime,
         const std::vector<char>&);
+    std::vector<std::string> getFieldNames();
+    std::vector<std::pair<std::string, uint32_t> > getHistogram(const std::string& query, const std::string& field, const std::string& labeltype);
+
     std::vector<std::string> getBackEnds();
+    void setEventListener(EventListener* eListener);
+    int countKeywords(const std::string& keywordmatch,
+        const std::vector<std::string>& fieldnames);
+    std::vector<std::string> getKeywords(const std::string& keywordmatch,
+        const std::vector<std::string>& fieldnames,
+        uint32_t max, uint32_t offset);
 };
 
 #endif
