@@ -18,18 +18,18 @@
  * Boston, MA 02110-1301, USA.
  */
 #include "socketclient.h"
-#include "filters.h"
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <errno.h>
 #include <assert.h>
 #include <sstream>
+#include <unistd.h>
 using namespace std;
 
 #if defined(__APPLE__)
 #define SOCKET_NOSIGNAL SO_NOSIGPIPE
-#elif defined( unix )
+#elif defined( MSG_NOSIGNAL )
 #define SOCKET_NOSIGNAL MSG_NOSIGNAL
 #else
 #define SOCKET_NOSIGNAL 0
@@ -75,6 +75,7 @@ SocketClient::readResponse(int sd) {
     string line;
     char c;
     while (true) {
+        // read characters one by one
         int r = recv(sd, &c, 1, 0);
         if (r < 0) {
             error = "Error reading from socket: ";
@@ -139,7 +140,7 @@ SocketClient::countHits(const string &query) {
     return count;
 }
 ClientInterface::Hits
-SocketClient::getHits(const string &query, int max, int off) {
+SocketClient::getHits(const string &query, uint32_t max, uint32_t off) {
     response.clear();
     request.clear();
     request.push_back("query");
@@ -179,7 +180,7 @@ SocketClient::getHits(const string &query, int max, int off) {
                 break;
             }
             string n(s, v-s);
-            h.properties.insert(make_pair(n,v+1));
+            h.properties.insert(make_pair<const string,string>(n,v+1));
             ++i;
         }
         hits.hits.push_back(h);
@@ -205,7 +206,7 @@ SocketClient::getStatus() {
     close(sd);
     for (uint i=0; i<response.size(); ++i) {
         string s = response[i];
-        uint p = s.find(":");
+        string::size_type p = s.find(":");
         if (p == string::npos) {
             printf("''%s''\n", s.c_str());
             status.clear();
@@ -296,77 +297,13 @@ SocketClient::setIndexedDirectories(set<string> dirs) {
     close(sd);
     return "";
 }
-multimap<int,string>
-SocketClient::getFilteringRules() {
-    multimap<int,string> r;
-    request.clear();
-    response.clear();
-    request.push_back("getFilteringRules");
-    int sd = open();
-    if (sd < 0) {
-        return r;
-    }
-    sendRequest(sd);
-    readResponse(sd);
-    close(sd);
-    
-    // response structure:
-    // LINE 0: FILTER_RTTI-TOT_RULES_NUMBER
-    // ... rules ...
-    // LINE $RULES_NUMBER: FILTER_RTTI-TOT_RULES_NUMBER
-    // ... rules ...
-    int filterRTTI = 0;
-    unsigned int filterNum = 0;
-    int unsigned i = 0;
-    
-    while ((i < response.size()) && (sscanf(response[i].c_str(), "%i-%u", &filterRTTI, &filterNum) != 0))
-    {
-        i++;
-        for (unsigned int ub = i + filterNum; (i < ub) && (i < response.size()); i++)
-            r.insert (make_pair(filterRTTI, response[i]));
-    }
-    
-    return r;
-}
 void
-SocketClient::setFilteringRules(const multimap<int,string>& rules) {
-    request.clear();
-    request.push_back("setFilteringRules");
-    
-    multimap<int,string>::const_iterator lb, ub, i;
-    char buffer[500];
-        
-    lb = rules.lower_bound(PathFilter::RTTI);
-    ub = rules.upper_bound(PathFilter::RTTI);
-        
-    // request structure:
-    // LINE 0: FILTER_RTTI-TOT_RULES_NUMBER
-    // ... rules ...
-    // LINE $RULES_NUMBER: FILTER_RTTI-TOT_RULES_NUMBER
-    // ... rules ...
-        
-    snprintf (buffer, 500*sizeof(char), "%i-%u",PathFilter::RTTI, rules.count(PathFilter::RTTI));
-    request.push_back(string(buffer));
-    for (i = lb; i != ub; ++i) {
-        request.push_back(i->second);
-    }
-        
-    lb = rules.lower_bound(PatternFilter::RTTI);
-    ub = rules.upper_bound(PatternFilter::RTTI);
-        
-    snprintf (buffer, 500*sizeof(char), "%i-%u",PatternFilter::RTTI, rules.count(PatternFilter::RTTI));
-    request.push_back(string(buffer));
-    for (i = lb; i != ub; ++i) {
-        request.push_back(i->second);
-    }
-    
-    int sd = open();
-    if (sd < 0) {
-        return ;
-    }
-    sendRequest(sd);
-    readResponse(sd);
-    close(sd);
+SocketClient::setFilters(const vector<pair<bool,string> >&rules){
+}
+vector<pair<bool,string> >
+SocketClient::getFilters() {
+    vector<pair<bool,string> > f;
+    return f;
 }
 set<string>
 SocketClient::getIndexedFiles() {
@@ -388,8 +325,8 @@ SocketClient::getIndexedFiles() {
     return r;
 }
 void
-SocketClient::indexFile(const std::string &path, uint64_t mtime,
-        const std::vector<char>& content) {
+SocketClient::indexFile(const string &path, uint64_t mtime,
+        const vector<char>& content) {
     printf("so you want me to send a file to strigi?\n");
     request.clear();
     response.clear();
@@ -400,4 +337,27 @@ SocketClient::indexFile(const std::string &path, uint64_t mtime,
     request.push_back(out.str());
     request.push_back(&content[0]);
 }
-
+vector<string>
+SocketClient::getFieldNames() {
+    fprintf(stderr, "SocketClient::getFieldNames is not implemented yet\n");
+    return vector<string>();
+}
+vector<pair<string, uint32_t> >
+SocketClient::getHistogram(const string& query, const string& field,
+        const string& labeltype) {
+    fprintf(stderr, "SocketClient::getHistogram is not implemented yet\n");
+    return vector<pair<string, uint32_t> >();
+}
+int
+SocketClient::countKeywords(const string& keywordmatch,
+        const vector<string>& fieldnames) {
+    fprintf(stderr, "SocketClient::countKeywords is not implemented yet\n");
+    return 0;
+}
+vector<string>
+SocketClient::getKeywords(const string& keywordprefix,
+        const vector<string>& fieldnames,
+        uint32_t max, uint32_t offset) {
+    fprintf(stderr, "SocketClient::getKeywords is not implemented yet\n");
+    return vector<string>();
+}
