@@ -35,20 +35,29 @@ private:
 public:
     const std::string& getError() const { return error; }
     void setSocketName(const std::string& socketname);
-    int countHits(const std::string &query);
-    Hits getHits(const std::string &query, int max, int off);
+    int32_t countHits(const std::string &query);
+    Hits getHits(const std::string &query, uint32_t max, uint32_t off);
     std::map<std::string, std::string> getStatus();
     std::string stopDaemon();
     std::string startIndexing();
     std::string stopIndexing();
     std::set<std::string> getIndexedDirectories();
     std::string setIndexedDirectories(std::set<std::string>);
-    std::multimap<int,std::string> getFilteringRules();
-    void setFilteringRules(const std::multimap<int,std::string>&);
+    void setFilters(const std::vector<std::pair<bool,std::string> >& rules);
+    std::vector<std::pair<bool,std::string> > getFilters();
     std::set<std::string> getIndexedFiles();
     void indexFile(const std::string &path, uint64_t mtime,
         const std::vector<char>&);
+    std::vector<std::string> getFieldNames();
+    std::vector<std::pair<std::string, uint32_t> > getHistogram(
+        const std::string& query, const std::string& field,
+        const std::string& labeltype);
     std::vector<std::string> getBackEnds();
+    int countKeywords(const std::string& keywordmatch,
+        const std::vector<std::string>& fieldnames);
+    std::vector<std::string> getKeywords(const std::string& keywordmatch,
+        const std::vector<std::string>& fieldnames,
+        uint32_t max, uint32_t offset);
 };
 
 #endif
