@@ -18,7 +18,7 @@
  * Boston, MA 02110-1301, USA.
  */
 #include "strigithread.h"
-#include "../streamindexer/strigi_thread.h"
+#include "strigi_thread.h"
 #include "strigilogging.h"
 #include <string>
 #include <cstring>
@@ -85,27 +85,23 @@ threadstarter(void *d) {
     memset(&param, 0, sizeof(param));
     param.sched_priority = 0;
     StrigiThread* thread = static_cast<StrigiThread*>(d);
-    printf("pri0: %i\n", thread->getPriority());
 #ifndef __APPLE__
-    printf("pri1: %i\n", thread->getPriority());
     if (thread->getPriority() > 0) {
 #ifndef SCHED_BATCH
 #define SCHED_BATCH 3
 #endif
-        // renice
-        int r = setpriority(PRIO_PROCESS, 0, thread->getPriority());
+        // renice the thread
+        int r  = setpriority(PRIO_PROCESS, 0, thread->getPriority());
         if (r != 0) {
             STRIGI_LOG_ERROR (string("strigi.daemon.") + thread->name
                 + ".threadstarter",
                 string("error setting priority: ") + strerror(errno))
         }
-        // in addition do sched_batch
         r = sched_setscheduler(0, SCHED_BATCH, &param);
         if (r != 0) {
-            STRIGI_LOG_ERROR (string("strigi.daemon.") + thread->name
-                    + ".threadstarter",
-                    string("error setting priority: ") + strerror(errno))
-            //nice(20);
+            STRIGI_LOG_INFO (string("strigi.daemon.") + thread->name
+                + ".threadstarter",
+                string("error setting to batch: ") + strerror(errno))
         }
 #ifdef HAVE_LINUXIOPRIO
     sys_ioprio_set(IOPRIO_WHO_PROCESS, 0, IOPRIO_CLASS_IDLE);
@@ -117,6 +113,7 @@ threadstarter(void *d) {
     thread->run(0);
     STRIGI_LOG_DEBUG(string("strigi.daemon.") + thread->name + ".threadstarter", "end of thread");
     STRIGI_THREAD_EXIT(0);
+    return 0;
 }
 
 StrigiThread::StrigiThread(const char* n) :state(Idling),thread(0),  name(n) {
@@ -153,7 +150,7 @@ StrigiThread::getStringState() {
         break;
     case Stopping:
         str = "stopping";
-        break; 
+        break;
     }
     return str;
 }
@@ -183,7 +180,7 @@ StrigiThread::stop() {
         // signal the thread to wake up
         pthread_kill(thread, SIGALRM);
         // wait for the thread to finish
-        STRIGI_THREAD_JOIN(thread, 0);
+        STRIGI_THREAD_JOIN(thread);
     }
     thread = 0;
 }
