@@ -21,16 +21,15 @@
 #include "indexer.h"
 #include "filelister.h"
 #include "filereader.h"
-#include "filtermanager.h"
 #include <sys/stat.h>
 
 using namespace std;
 
 Indexer *Indexer::workingIndexer;
 
-Indexer::Indexer(FilterManager* filtermanager, jstreams::IndexWriter* w)
-        : m_indexer(w) {
-    m_lister = new FileLister (filtermanager);
+Indexer::Indexer(jstreams::IndexWriter& w, jstreams::IndexerConfiguration& c)
+        : m_indexer(w, c) {
+    m_lister = new FileLister(c);
 }
 Indexer::~Indexer() {
     delete m_lister;
@@ -59,11 +58,10 @@ Indexer::index(const char *dir) {
         m_lister->listFiles(dir);
     }
 }
-bool
+void
 Indexer::addFileCallback(const char* path, uint dirlen, uint len,
         time_t mtime) {
     workingIndexer->doFile(path);
-    return true;
 }
 void
 Indexer::doFile(const char* filepath) {
