@@ -24,19 +24,18 @@
 #include "streamindexer.h"
 
 class FileLister;
-class FilterManager;
 
 class Indexer {
 private:
     FileLister* m_lister;
     jstreams::StreamIndexer m_indexer;
 
-    static bool addFileCallback(const char* fullpath, uint dirlen,
+    static void addFileCallback(const char* fullpath, uint dirlen,
         uint len, time_t mtime);
     static Indexer *workingIndexer;
     void doFile(const char* filepath);
 public:
-    Indexer(FilterManager* filtermanager, jstreams::IndexWriter* writer);
+    Indexer(jstreams::IndexWriter& writer, jstreams::IndexerConfiguration& c);
     ~Indexer();
     void index(const char *dir);
 };
