@@ -22,11 +22,13 @@
 #include "filereader.h"
 #include "filelister.h"
 using namespace std;
+using namespace jstreams;
 
 Indexer *Indexer::workingIndexer;
 
-Indexer::Indexer(const char *indexdir) :m_indexdir(indexdir),
-        m_manager(indexdir), m_indexer(m_manager.getIndexWriter()) {
+Indexer::Indexer(const char *indexdir, IndexerConfiguration& ic)
+        :m_indexdir(indexdir), m_manager(indexdir),
+         m_indexer(*m_manager.getIndexWriter(), ic) {
 }
 Indexer::~Indexer() {
 }
@@ -45,11 +47,10 @@ Indexer::index(const char *dir) {
         m_lister->listFiles(dir);
     }
 }
-bool
+void
 Indexer::addFileCallback(const char* path, uint dirlen, uint len,
         time_t mtime) {
     workingIndexer->doFile(path);
-    return true;
 }
 void
 Indexer::doFile(const char* filepath) {
