@@ -34,12 +34,12 @@ private:
     EstraierIndexManager m_manager;
     jstreams::StreamIndexer m_indexer;
 
-    static bool addFileCallback(const char* fullpath, uint dirlen, uint len,
+    static void addFileCallback(const char* fullpath, uint dirlen, uint len,
         time_t mtime);
     static Indexer *workingIndexer;
     void doFile(const char* filepath);
 public:
-    explicit Indexer(const char *indexdir);
+    Indexer(const char *indexdir, jstreams::IndexerConfiguration& ic);
     ~Indexer();
     void index(const char *dir);
 };
