@@ -33,8 +33,7 @@ using namespace jstreams;
 class StrigiHtmlGui::Private {
 private:
     HtmlHelper* h;
-    string highlightTerms(const string& t, const Query& q,
-        const vector<string>& fields) const;
+    string highlightTerms(const string& t, const Query& q) const;
     void printSearchResult(ostream& out,
         const jstreams::IndexedDocument& doc, const Query& q) const;
 public:
@@ -125,7 +124,7 @@ startDaemon() {
             break;
         }
     }
-    
+
 }
 void
 StrigiHtmlGui::printStatus(ostream& out, const string& path,
@@ -294,22 +293,29 @@ StrigiHtmlGui::printSearch(ostream& out, const string& path,
         out << "</div>";
     }
 }
-string
-StrigiHtmlGui::Private::highlightTerms(const string& t, const Query& q,
-        const vector<string>& fields) const {
-    string out = t;
-    vector<string> terms;
-    vector<string>::const_iterator i;
-    for (i = fields.begin(); i != fields.end(); ++i) {
-        map<string, set<string> >::const_iterator j = q.getIncludes().find(*i);
-        if (j != q.getIncludes().end()) {
-            set<string>::const_iterator k;
-            for (k = j->second.begin(); k != j->second.end(); ++k) {
-                terms.push_back(*k);
-            }
-        }
+set<string>
+getTerms(const Query& q) {
+    set<string> terms;
+    if (q.getOccurrence() == Query::MUST_NOT) {
+        return terms;
     }
-    return h->highlight(out, terms);
+    if (q.getExpression().size() > 0) {
+        terms.insert(q.getExpression());
+    }
+    list<Query>::const_iterator j;
+    for (j = q.getTerms().begin(); j != q.getTerms().end(); ++j) {
+        set<string> t = getTerms(*j);
+        copy(t.begin(), t.end(), inserter(terms, terms.begin()));
+    }
+    return terms;
+}
+string
+StrigiHtmlGui::Private::highlightTerms(const string& t, const Query& q) const {
+    vector<string> terms;
+    set<string> termset = getTerms(q);
+    copy(termset.begin(), termset.end(), back_inserter(terms));
+    string out = h->highlight(t, terms);
+    return out;
 }
 void
 StrigiHtmlGui::printMenu(ostream& out, const string& path,
@@ -427,17 +433,12 @@ StrigiHtmlGui::Private::printSearchResult(ostream& out,
     out << doc.score << ", mime-type: " << doc.mimetype.c_str() << ", size: ";
     out << doc.size << ", last modified: " << h->formatDate(doc.mtime);*/
     string fragment = h->escapeString(doc.fragment);
-    vector<string> fields;
-    fields.push_back("");
-    fields.push_back("content");
-    fragment = highlightTerms(fragment, query, fields);
+    fragment = highlightTerms(fragment, query);
     out << "<div class='fragment'>" << fragment << "</div>";
-    fields.clear();
     string path = h->escapeString(doc.uri);
-    path = highlightTerms(path, query, fields);
 
     out << "<div class='path'>";
-    uint p = path.find('/');
+    string::size_type p = path.find('/');
     int pp = 0;
     string subpath;
     while (p != string::npos) {
@@ -470,7 +471,8 @@ StrigiHtmlGui::Private::printSearchResult(ostream& out,
 void
 StrigiHtmlGui::Private::printSearchResults(ostream& out,
         const ClientInterface::Hits& hits, const string& q) const {
-    Query query(q, 0, 0);
+    QueryParser parser;
+    Query query = parser.buildQuery(q, 0, 0);
     vector<jstreams::IndexedDocument>::const_iterator i;
     for (i = hits.hits.begin(); i != hits.hits.end(); ++i) {
         printSearchResult(out, *i, query);
