@@ -2,7 +2,9 @@
 #include "indexmanagertests.h"
 #include "indexreader.h"
 #include "indexwriter.h"
+#include "indexable.h"
 #include "indexmanager.h"
+#include "indexerconfiguration.h"
 #include "query.h"
 #include "strigi_thread.h"
 #include <sstream>
@@ -12,63 +14,39 @@ using namespace jstreams;
 
 class IndexManagerTester {
 private:
-    STRIGI_MUTEX_DEFINE(lock);
-    int errors;
+    StrigiMutex lock;
     IndexManager* manager;
     IndexWriter* writer;
     IndexReader* reader;
+    StreamIndexer si;
 public:
-    IndexManagerTester(IndexManager* m) :errors(0), manager(m) {
-        writer = manager->getIndexWriter();
+    IndexManagerTester(IndexManager* m, IndexerConfiguration& ic)
+            : manager(m), writer(manager->getIndexWriter()),
+              si(*writer, ic) {
         reader = manager->getIndexReader();
-        STRIGI_MUTEX_INIT(&lock);
     }
     ~IndexManagerTester() {
-        STRIGI_MUTEX_DESTROY(&lock);
     }
-    int runUnthreadedTests();
-    int runThreadedTests();
-    void cleanErrors() {
-        STRIGI_MUTEX_LOCK(&lock);
-        errors = 0;
-        STRIGI_MUTEX_UNLOCK(&lock);
-    }
-    int getErrors() {
-        int n;
-        STRIGI_MUTEX_LOCK(&lock);
-        n = errors;
-        STRIGI_MUTEX_UNLOCK(&lock);
-        return errors;
-    }
-    void addErrors(int n) {
-        STRIGI_MUTEX_LOCK(&lock);
-        errors += n;
-        STRIGI_MUTEX_UNLOCK(&lock);
-    }
-    int addAndCount();
-    int testNumberQuery();
+    void runUnthreadedTests();
+    void runThreadedTests();
+    void addAndCount();
+    void testNumberQuery();
 };
-int
+void
 IndexManagerTester::runUnthreadedTests() {
-    int n = 0;
 
-    // tests that only need return 0 when not threaded
-    n += addAndCount();
-    n += testNumberQuery();
-
-    addErrors(n);
-    return n;
-}
-int
-IndexManagerTester::runThreadedTests() {
-    int n = 0;
     // tests that only need return 0 when not threaded
     addAndCount();
     testNumberQuery();
-    addErrors(n);
-    return n;
+
 }
-int
+void
+IndexManagerTester::runThreadedTests() {
+    // tests that only need return 0 when not threaded
+    addAndCount();
+    testNumberQuery();
+}
+void
 IndexManagerTester::addAndCount() {
     writer->deleteAllEntries();
     int m = 20;
@@ -76,14 +54,15 @@ IndexManagerTester::addAndCount() {
     for (int i=0; i<m; ++i) {
         str << "/" << i;
         string s(str.str());
-        { Indexable idx(s, 0, writer, 0); }
+        { Indexable idx(s, 0, *writer, si); }
         str.str("");
     }
     writer->commit();
     int n = reader->countDocuments();
-    return n != m;
+    if (n != m) fprintf(stderr, "%i != %i\n", n, m);
+    VERIFY(n == m);
 }
-int
+void
 IndexManagerTester::testNumberQuery() {
     writer->deleteAllEntries();
     // add numbers to the database
@@ -95,58 +74,55 @@ IndexManagerTester::testNumberQuery() {
         string value(str.str());
         string name('/'+value);
         {
-             Indexable idx(name, 0, writer, 0);
+             Indexable idx(name, 0, *writer, si);
              idx.setField(size, value);
         }
         str.str("");
     }
     writer->commit();
-    Query q("size:>0", -1, 0);
+    QueryParser parser;
+    Query q = parser.buildQuery("size:>0", -1, 0);
     int count = reader->countHits(q);
-    printf("count: %i\n", count);
-    return count != m;
+    if (count != m) fprintf(stderr, "%i != %i\n", count, m);
+    VERIFY(count == m);
 }
 /* below here the threading plumbing is done */
-void*
-threadstarter(void *d) {
-    IndexManagerTests* tester = static_cast<IndexManagerTests*>(d);
+STRIGI_THREAD_FUNCTION(threadstarter,d) {
+//    IndexManagerTests* tester = static_cast<IndexManagerTests*>(d);
 //    tester->runThreadedTests();
     STRIGI_THREAD_EXIT(0);
+    return 0;
 }
-IndexManagerTests::IndexManagerTests(jstreams::IndexManager* m)
-    :tester (new IndexManagerTester(m)) {
+IndexManagerTests::IndexManagerTests(jstreams::IndexManager* m,
+        IndexerConfiguration& ic)
+    :tester (new IndexManagerTester(m, ic)) {
 }
 IndexManagerTests::~IndexManagerTests() {
     delete tester;
 }
-int
+void
 IndexManagerTests::testAllInThreads(int n) {
-    tester->cleanErrors();
     STRIGI_THREAD_TYPE* thread = new STRIGI_THREAD_TYPE[n];
     for (int i=0; i<n; ++i) {
-        STRIGI_THREAD_CREATE(thread+i, threadstarter, this);
+        STRIGI_THREAD_CREATE(&thread[i], threadstarter, this);
     }
     for (int i=0; i<n; ++i) {
-        STRIGI_THREAD_JOIN(thread[i], 0);
+        STRIGI_THREAD_JOIN(thread[i]);
     }
 
     delete [] thread;
-    return tester->getErrors();
 }
 
-int
+void
 IndexManagerTests::testAll() {
-    tester->cleanErrors();
-    int n = 0;
-    n += tester->runUnthreadedTests();
-    n += tester->runThreadedTests();
-    return n;
+    tester->runUnthreadedTests();
+    tester->runThreadedTests();
 }
-int
+void
 IndexManagerTests::runUnthreadedTests() {
-    return tester->runUnthreadedTests();
+    tester->runUnthreadedTests();
 }
-int
+void
 IndexManagerTests::runThreadedTests() {
-    return tester->runThreadedTests();
+    tester->runThreadedTests();
 }
