@@ -1,8 +1,11 @@
 #ifndef INDEXWRITERTESTS_H
 #define INDEXWRITERTESTS_H
 
+#include "verify.h"
+
 namespace jstreams {
     class IndexWriter;
+    class IndexerConfiguration;
 }
 
 class IndexWriterTester;
@@ -10,7 +13,8 @@ class IndexWriterTests {
 private:
     IndexWriterTester* tester;
 public:
-    IndexWriterTests(jstreams::IndexWriter* w);
+    IndexWriterTests(jstreams::IndexWriter& w,
+        jstreams::IndexerConfiguration& ic);
     ~IndexWriterTests();
     int testAll();
 };
