@@ -18,19 +18,19 @@
  * Boston, MA 02110-1301, USA.
  */
 #include "jstreamsconfig.h"
+#include <CLucene.h>
 #include "cluceneindexmanager.h"
 #include "cluceneindexwriter.h"
 #include "cluceneindexreader.h"
-#include <CLucene.h>
 #include <sys/types.h>
+#include <time.h>
+#include "timeofday.h"
 #include "stgdirent.h" //our dirent compatibility header... uses native if available
 
 using namespace lucene::index;
 using lucene::analysis::standard::StandardAnalyzer;
 using lucene::store::FSDirectory;
 
-StrigiMutex CLuceneIndexManager::lock;
-
 jstreams::IndexManager*
 createCLuceneIndexManager(const char* path) {
     return new CLuceneIndexManager(path);
@@ -41,22 +41,24 @@ int CLuceneIndexManager::numberOfManagers = 0;
 CLuceneIndexManager::CLuceneIndexManager(const std::string& path)
         {//: bitsets(this) {
     ++numberOfManagers;
-    dblock = &lock;
     dbdir = path;
-    indexreader = 0;
     indexwriter = 0;
-    version = 0;
     writer = new CLuceneIndexWriter(this);
-    reader = new CLuceneIndexReader(this);
     analyzer = new StandardAnalyzer();
+    mtime = 0;
+
+    //remove any old segments lying around from crashes, etc
+    //writer->cleanUp();
     // make sure there's at least an index
     openWriter();
 }
 CLuceneIndexManager::~CLuceneIndexManager() {
     // close the writer and analyzer
     delete writer;
-    delete reader;
-    closeReader();
+    std::map<STRIGI_THREAD_TYPE, CLuceneIndexReader*>::iterator r;
+    for (r = readers.begin(); r != readers.end(); ++r) {
+        delete r->second;
+    }
     closeWriter();
     delete analyzer;
     if (--numberOfManagers == 0) {
@@ -66,7 +68,23 @@ CLuceneIndexManager::~CLuceneIndexManager() {
 }
 jstreams::IndexReader*
 CLuceneIndexManager::getIndexReader() {
-    return reader;
+    return getReader();
+}
+CLuceneIndexReader*
+CLuceneIndexManager::getReader() {
+    // TODO check if we should update/reopen the reader
+    STRIGI_THREAD_TYPE self = STRIGI_THREAD_SELF();
+    CLuceneIndexReader* r;
+    STRIGI_MUTEX_LOCK(&lock.lock);
+    r = readers[self];
+    STRIGI_MUTEX_UNLOCK(&lock.lock);
+    if (r == 0) {
+        r = new CLuceneIndexReader(this, dbdir);
+        STRIGI_MUTEX_LOCK(&lock.lock);
+        readers[self] = r;
+        STRIGI_MUTEX_UNLOCK(&lock.lock);
+    }
+    return r;
 }
 jstreams::IndexWriter*
 CLuceneIndexManager::getIndexWriter() {
@@ -78,53 +96,18 @@ CLuceneIndexManager::getBitSets() {
 }*/
 IndexWriter*
 CLuceneIndexManager::refWriter() {
-    STRIGI_MUTEX_LOCK(&dblock->lock);
+    STRIGI_MUTEX_LOCK(&writelock.lock);
     if (indexwriter == 0) {
-        closeReader();
         openWriter();
     }
     return indexwriter;
 }
 void
 CLuceneIndexManager::derefWriter() {
-    STRIGI_MUTEX_UNLOCK(&dblock->lock);
-}
-IndexReader*
-CLuceneIndexManager::refReader() {
-    STRIGI_MUTEX_LOCK(&dblock->lock);
-    if (indexreader == 0) {
-        closeWriter();
-        openReader();
-    }
-    return indexreader;
-}
-void
-CLuceneIndexManager::derefReader() {
-    STRIGI_MUTEX_UNLOCK(&dblock->lock);
-}
-void
-CLuceneIndexManager::openReader() {
-    try {
-//        printf("reader at %s\n", dbdir.c_str());
-        indexreader = IndexReader::open(dbdir.c_str());
-    } catch (CLuceneError& err) {
-        printf("could not create reader: %s\n", err.what());
-    }
-}
-void
-CLuceneIndexManager::closeReader() {
-    if (indexreader == 0) return;
-    try {
-        indexreader->close();
-    } catch (CLuceneError& err) {
-        printf("could not close clucene: %s\n", err.what());
-    }
-    delete indexreader;
-    indexreader = 0;
+    STRIGI_MUTEX_UNLOCK(&writelock.lock);
 }
 void
 CLuceneIndexManager::openWriter(bool truncate) {
-    version++;
     try {
         if (!truncate && IndexReader::indexExists(dbdir.c_str())) {
             if (IndexReader::isLocked(dbdir.c_str())) {
@@ -149,20 +132,7 @@ CLuceneIndexManager::closeWriter() {
 }
 int
 CLuceneIndexManager::docCount() {
-    int count = 0;
-    STRIGI_MUTEX_LOCK(&dblock->lock);
-    if (indexwriter) {
-        count = indexwriter->docCount();
-    } else {
-        if (indexreader == 0) {
-            openReader();
-        }
-        if (indexreader) {
-            count = indexreader->numDocs();
-        }
-    }
-    STRIGI_MUTEX_UNLOCK(&dblock->lock);
-    return count;
+    return getReader()->reader->numDocs();
 }
 int64_t
 CLuceneIndexManager::getIndexSize() {
@@ -193,7 +163,95 @@ CLuceneIndexManager::getIndexSize() {
 }
 void
 CLuceneIndexManager::deleteIndex() {
-    closeReader();
+    // todo: close all readers
     closeWriter();
     openWriter(true);
 }
+time_t
+CLuceneIndexManager::getIndexMTime() {
+    time_t t;
+    STRIGI_MUTEX_LOCK(&lock.lock);
+    t = mtime;
+    STRIGI_MUTEX_UNLOCK(&lock.lock);
+    return t;
+}
+void
+CLuceneIndexManager::setIndexMTime() {
+    struct timeval t;
+    gettimeofday(&t, 0);
+    STRIGI_MUTEX_LOCK(&lock.lock);
+    mtime = t.tv_sec;
+    STRIGI_MUTEX_UNLOCK(&lock.lock);
+}
+std::wstring
+utf8toucs2(const char*p, const char*e) {
+    wstring ucs2;
+    ucs2.reserve(3*(e-p));
+    wchar_t w = 0;
+    char nb = 0;
+    while (p < e) {
+        char c = *p;
+        if (nb--) {
+            w = (w<<6) + (c & 0x3f);
+        } else if ((0xE0 & c) == 0xC0) {
+            w = c & 0x1F;
+            nb = 0;
+        } else if ((0xF0 & c) == 0xE0) {
+            w = c & 0x0F;
+            nb = 1;
+        } else if ((0xF8 & c) == 0xF0) {
+            w = c & 0x07;
+            nb = 2;
+        } else {
+            w = (w<<6) + (c&0x7F);
+            ucs2 += w;
+            w = 0;
+            nb = 0;
+        }
+        p++;
+    }
+    return ucs2;
+}
+std::wstring
+utf8toucs2(const char* p) {
+    return utf8toucs2(p, p+strlen(p));
+}
+std::wstring
+utf8toucs2(const std::string& utf8) {
+    const char* p = utf8.c_str();
+    const char* e = p + utf8.length();
+    return utf8toucs2(p, e);
+}
+std::string
+wchartoutf8(const wchar_t* p, const wchar_t* e) {
+    string utf8;
+    utf8.reserve((int)(1.5*(e-p)));
+    while (p < e) {
+        wchar_t c = *p;
+        if (c < 0x80) {
+            utf8 += (char)c;
+        } else if (c < 0x800) {
+            char c2 = (char)((c & 0x3f) | 0x80);
+            utf8 += (c>>6) | 0xc0;
+            utf8 += c2;
+        } else if (c < 0x10000) {
+            char c3 = (char)((c & 0x3f) | 0x80);
+            char c2 = (char)(((c>>6) & 0x3f) | 0x80);
+            utf8 += (c>>12) | 0xe0;
+            utf8 += c2;
+            utf8 += c3;
+        }
+        p++;
+    }
+    return utf8;
+}
+std::string
+wchartoutf8(const wchar_t* p) {
+    return wchartoutf8(p, p+wcslen(p));
+}
+std::string
+wchartoutf8(const std::wstring& wchar) {
+    const wchar_t *p = wchar.c_str();
+    const wchar_t *e = p+wchar.length();
+    return wchartoutf8(p, e);
+}
