@@ -22,6 +22,12 @@
 
 #include "indexreader.h"
 #include <map>
+#include <time.h>
+namespace lucene {
+    namespace index {
+        class IndexReader;
+    }
+}
 
 class CLuceneIndexManager;
 class CLuceneIndexReader : public jstreams::IndexReader {
@@ -29,13 +35,20 @@ friend class CLuceneIndexManager;
 private:
     CLuceneIndexManager* manager;
     class Private;
-    int countversion;
-    int32_t count;
+    int32_t wordcount;
+    int32_t doccount;
+    const std::string dbdir;
+    time_t otime;
 
-    CLuceneIndexReader(CLuceneIndexManager* m);
+    CLuceneIndexReader(CLuceneIndexManager* m, const std::string& dbdir);
     ~CLuceneIndexReader();
+    static const TCHAR* mapId(const wchar_t* id);
+	static std::wstring mapId(const char* id);
+    void openReader();
+    void closeReader();
+    bool checkReader(bool ensureCurrent = false);
 
-    static const char* mapId(const std::string& id);
+    friend class CLuceneIndexReader::Private;
 public:
     int32_t countHits(const jstreams::Query&);
     std::vector<jstreams::IndexedDocument> query(const jstreams::Query&);
@@ -45,6 +58,17 @@ public:
     int64_t getIndexSize();
     int64_t getDocumentId(const std::string& uri);
     time_t getMTime(int64_t docid);
+    static void addMapping(const TCHAR* from, const TCHAR* to);
+    lucene::index::IndexReader* reader;
+    std::vector<std::pair<std::string,uint32_t> > getHistogram(
+            const std::string& query, const std::string& fieldname,
+            const std::string& labeltype);
+    std::vector<std::string> getFieldNames();
+    int32_t countKeywords(const std::string& keywordprefix,
+        const std::vector<std::string>& fieldnames);
+    std::vector<std::string> getKeywords(const std::string& keywordmatch,
+        const std::vector<std::string>& fieldnames,
+        uint32_t max, uint32_t offset);
 };
 
 #endif
