@@ -18,11 +18,10 @@
  * Boston, MA 02110-1301, USA.
  */
 #include "jstreamsconfig.h"
-#include "indexer.h"
 #include <CLucene.h>
+#include "indexer.h"
 #include "filelister.h"
 #include "filereader.h"
-#include "filtermanager.h"
 #include "cluceneindexmanager.h"
 
 using lucene::index::IndexWriter;
@@ -30,10 +29,11 @@ using namespace jstreams;
 
 Indexer *Indexer::workingIndexer;
 
-Indexer::Indexer(const char *indexdir, FilterManager* filtermanager) :m_indexdir(indexdir),
-        m_manager(indexdir), m_writer(&m_manager), m_indexer(&m_writer)
+Indexer::Indexer(const char *indexdir, IndexerConfiguration& ic)
+        : m_indexdir(indexdir), m_manager(indexdir), m_writer(&m_manager),
+          m_indexer(m_writer, ic)
 {
-    m_lister = new FileLister (filtermanager);
+    m_lister = new FileLister(ic);
 }
 Indexer::~Indexer() {
     delete m_lister;
@@ -56,11 +56,10 @@ Indexer::index(const char *dir) {
         m_lister->listFiles(dir);
     }
 }
-bool
+void
 Indexer::addFileCallback(const char* path, uint dirlen, uint len,
         time_t mtime) {
     workingIndexer->doFile(path);
-    return true;
 }
 void
 Indexer::doFile(const char* filepath) {
