@@ -25,7 +25,6 @@
 #include "streamindexer.h"
 
 class FileLister;
-class FilterManager;
 
 class Indexer {
 private:
@@ -35,12 +34,12 @@ private:
     CLuceneIndexWriter m_writer;
     jstreams::StreamIndexer m_indexer;
 
-    static bool addFileCallback(const char* path, uint dirlen, uint len,
+    static void addFileCallback(const char* path, uint dirlen, uint len,
         time_t mtime);
     static Indexer *workingIndexer;
     void doFile(const char* filepath);
 public:
-    Indexer(const char *indexdir, FilterManager* filtermanager);
+    Indexer(const char *indexdir, jstreams::IndexerConfiguration& ic);
     ~Indexer();
     void index(const char *dir);
 };
