@@ -22,23 +22,20 @@
 #define DLGLISTINDEXEDFILES_H
 
 #include <QDialog>
-#include <set>
-#include <string>
 
 class QListWidget;
 class QPushButton;
 
 class DlgListIndexedFiles : public QDialog {
 Q_OBJECT
-    
+
 public:
-    explicit DlgListIndexedFiles (std::set<std::string>& files,
-        QWidget* parent = 0);
+    explicit DlgListIndexedFiles(const QStringList& files, QWidget* parent = 0);
     ~DlgListIndexedFiles () {};
-    
+
 private slots:
     void accept();
-   
+
 private:
     QListWidget *listFiles;
     QPushButton *okButton;
