@@ -22,8 +22,8 @@
 
 #include <QtGui/QWidget>
 #include <QtCore/QMap>
+#include "strigiasyncclient.h"
 
-class Qt4StrigiClient;
 class QTabBar;
 class SearchView;
 class SearchTabs : public QWidget {
@@ -34,13 +34,14 @@ private:
     QMap<QString, int> tabqueries;
     QMap<QString, QString> querynames;
     QString query;
-    Qt4StrigiClient* strigi;
+    StrigiAsyncClient strigi;
 private slots:
     void handleHitsCount(const QString& query, int);
     void tabChanged(int);
 public:
-    SearchTabs(Qt4StrigiClient* s);
+    SearchTabs();
     void addTab(const QString& name, const QString& query);
+    SearchView* getSearchView() { return view; }
 public slots:
     void setQuery(const QString& slot);
 signals:
