@@ -17,7 +17,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#include "qt4strigiclient.h"
+//#include "qt4strigiclient.h"
 #include "searchview.h"
 #include "strigihtmlgui.h"
 #include <QtGui/QVBoxLayout>
@@ -28,6 +28,7 @@
 #include <QtCore/QDateTime>
 #include <QtCore/QUrl>
 #include <QtCore/QVariant>
+#include <sstream>
 
 using namespace std;
 
@@ -74,7 +75,7 @@ SearchViewHtmlHelper::encodeString(const string& url) {
 }
 string
 SearchViewHtmlHelper::escapeString(const string& line) {
-    return (const char*)Qt::escape(line.c_str()).toUtf8();
+    return (const char*)Qt::escape(QString::fromUtf8(line.c_str())).toUtf8();
 }
 string
 SearchViewHtmlHelper::formatDate(time_t date) {
@@ -98,6 +99,7 @@ SearchViewHtmlHelper::highlight(const std::string& text,
     int pos = 0;
     int lasts = -1;
     int laste = -1;
+    QRegExp nonword("\\W");
     while (pos >= 0 && out.length()+laste-lasts < maxlen) {
         int rep = -1;
         int len = 0;
@@ -110,9 +112,9 @@ SearchViewHtmlHelper::highlight(const std::string& text,
         }
         if (rep >= 0) {
             int s = (rep-pre > 0) ?rep-pre :0;
-            s = t.lastIndexOf(" ", s);
+            s = t.lastIndexOf(nonword, s);
             if (s == -1) s = (rep-pre < 0) ?0 : rep-pre;
-            int e = t.indexOf(" ", rep+len+post);
+            int e = t.indexOf(nonword, rep+len+post);
             if (e == -1) e = t.length();
             if (lasts == -1) {
                 lasts = s;
@@ -139,7 +141,7 @@ SearchViewHtmlHelper::highlight(const std::string& text,
     }
     return (const char*)out.toUtf8();
 }
-SearchView::SearchView(Qt4StrigiClient* k) :strigi(k) {
+SearchView::SearchView() {
     view = new QTextBrowser();
     QVBoxLayout *layout = new QVBoxLayout;
     layout->setMargin(0);
@@ -148,9 +150,9 @@ SearchView::SearchView(Qt4StrigiClient* k) :strigi(k) {
     htmlguihelper = new SearchViewHtmlHelper();
     htmlgui = new StrigiHtmlGui(htmlguihelper);
 
-    connect(strigi,
-        SIGNAL(gotHits(const QString&, const ClientInterface::Hits&)),
-        this, SLOT(handleHits(const QString&, const ClientInterface::Hits&)));
+    connect(&asyncstrigi,
+        SIGNAL(gotHits(const QString&, int, const QList<StrigiHit>&)),
+        this, SLOT(handleHits(const QString&, int, const QList<StrigiHit>&)));
     connect(view, SIGNAL(anchorClicked(const QUrl&)),
         this, SLOT(openItem(const QUrl&)));
 }
@@ -161,21 +163,47 @@ SearchView::~SearchView() {
 QString str(const string&s) {
     return QString::fromUtf8(s.c_str(), s.length());
 }
-#include <sstream>
+ClientInterface::Hits
+toID(const QList<StrigiHit>& hits) {
+    ClientInterface::Hits id;
+    foreach (const StrigiHit&h, hits) {
+        jstreams::IndexedDocument i;
+        i.uri.assign(h.uri.toUtf8());
+        i.score = h.score;
+        i.fragment.assign(h.fragment.toUtf8());
+        i.mimetype.assign(h.mimetype.toUtf8());
+        i.sha1.assign(h.sha1.toUtf8());
+        i.size = h.size;
+        i.mtime = h.mtime;
+        QMap<QString, QStringList>::const_iterator j;
+        for (j = h.properties.begin(); j != h.properties.end(); ++j) {
+            string name = (const char*)j.key().toUtf8();
+            for (int k = 0; k < j.value().size(); ++k) {
+                 string v = (const char*)j.value()[k].toUtf8();
+                 i.properties.insert(make_pair<string,string>(name, v));
+            }
+        }
+        id.hits.push_back(i);
+    }
+    return id;
+}
 void
-SearchView::handleHits(const QString& q, const ClientInterface::Hits& hits) {
+SearchView::handleHits(const QString& q, int offset,
+        const QList<StrigiHit>& hits) {
     view->clear();
     setEnabled(true);
     if (q != query) return;
     QUrl cssurl(":/strigi/result.css");
-    QVariant css = "h2{background:blue;}";
-//    view->document()->addResource(QTextDocument::StyleSheetResource,
-//        cssurl, css);
-    if (hits.hits.size() > 0) {
+    QVariant css = "";
+    view->document()->addResource(QTextDocument::StyleSheetResource,
+        cssurl, css);
+    if (hits.size() > 0) {
         ostringstream str;
-        htmlgui->printSearchResults(str, hits, (const char*)q.toUtf8());
-        QString html(str.str().c_str());
+        ClientInterface::Hits shits = toID(hits);
+        htmlgui->printSearchResults(str, shits, (const char*)q.toUtf8());
+        QString html(QString::fromUtf8(str.str().c_str()));
         view->setHtml(html);
+        emit gotHits(q);
     } else {
         view->append("no results");
     }
@@ -187,7 +215,8 @@ SearchView::setHTML(const QString& html) {
 void
 SearchView::setQuery(const QString& q) {
     query = q;
-    strigi->query(query);
+    asyncstrigi.clearRequests(StrigiAsyncClient::Query);
+    asyncstrigi.addGetQuery(query, 10, 0);
 }
 void
 SearchView::openItem(const QUrl& url) {
