@@ -17,17 +17,19 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#include "dlgpreferences.h"
+#include "dlgfilters.h"
 #include "dlglistindexedfiles.h"
 #include "simplesearchgui.h"
 #include "searchtabs.h"
-#include "socketclient.h"
+#include "histogram.h"
+#include "searchview.h"
 #include <QtGui/QListWidget>
 #include <QtGui/QListWidgetItem>
 #include <QtGui/QLineEdit>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QStackedWidget>
 #include <QtGui/QLabel>
+#include <QtGui/QDockWidget>
 #include <QtGui/QPushButton>
 #include <QtGui/QFileDialog>
 #include <QtGui/QComboBox>
@@ -38,6 +40,7 @@
 #include <QtCore/QDebug>
 #include <QtCore/QCoreApplication>
 #include <QtCore/QProcess>
+#include <QtCore/QTimer>
 #include <string>
 #include <map>
 #include <vector>
@@ -50,6 +53,7 @@ SimpleSearchGui::SimpleSearchGui (QWidget * parent, Qt::WFlags flags)
 
     QWidget* statuswidget = new QWidget();
     QVBoxLayout *statuslayout = new QVBoxLayout;
+    statuslayout->setMargin(0);
     statusview = new QLabel();
     statusview->setAlignment(Qt::AlignTop);
     statusview->setMargin(25);
@@ -57,6 +61,7 @@ SimpleSearchGui::SimpleSearchGui (QWidget * parent, Qt::WFlags flags)
     running = false;
     starting = true;
     indexeddirs = new QListWidget();
+    indexeddirs->setSelectionMode(QAbstractItemView::ExtendedSelection);
     adddir = new QPushButton("add directory");
     removedir = new QPushButton("remove directory");
     toggleindexing = new QPushButton("start indexing");
@@ -66,6 +71,13 @@ SimpleSearchGui::SimpleSearchGui (QWidget * parent, Qt::WFlags flags)
     hlayout->addWidget(toggledaemon);
     hlayout->addWidget(toggleindexing);
     statuslayout->addLayout(hlayout);
+
+    histogram = new Histogram();
+    histogram->setOrientation(Qt::Vertical);
+    fieldnames = new QComboBox();
+    fieldnames->addItems(strigi.getFieldNames());
+    fieldnames->setCurrentIndex(fieldnames->findText("mtime"));
+    histogram->setFieldName("mtime");
 /*    vector<string> backends = ClientInterface::getBackEnds();
     if (backends.size() > 1) {
         backendsList = new QComboBox();
@@ -84,7 +96,7 @@ SimpleSearchGui::SimpleSearchGui (QWidget * parent, Qt::WFlags flags)
     statuslayout->addLayout(hlayout);
     statuswidget->setLayout(statuslayout);
 
-    tabs = new SearchTabs(&strigi);
+    tabs = new SearchTabs();
     tabs->addTab("kde", "kde");
     tabs->addTab("msg", "mimetype:message/*");
     tabs->addTab("irc", "path:*konversation*log");
@@ -95,20 +107,31 @@ SimpleSearchGui::SimpleSearchGui (QWidget * parent, Qt::WFlags flags)
     tabs->addTab("all", "");
     mainview->addWidget(tabs);
     mainview->addWidget(statuswidget);
+    asyncstrigi.updateStatus();
     mainview->setCurrentIndex(1);
 
     queryfield = new QLineEdit();
     QVBoxLayout *layout = new QVBoxLayout;
     layout->addWidget(mainview);
     layout->addWidget(queryfield);
-   
+
+    QVBoxLayout* histlayout = new QVBoxLayout();
+    QDockWidget* histwidget = new QDockWidget();
+    histwidget->setFeatures(QDockWidget::NoDockWidgetFeatures);
+    QWidget* histw = new QWidget();
+    histw->setLayout(histlayout);
+    histwidget->setWidget(histw);
+    histlayout->addWidget(fieldnames);
+    histlayout->addWidget(histogram);
+    addDockWidget(Qt::LeftDockWidgetArea, histwidget);
+
     centralview = new QWidget();
     centralview->setLayout(layout);
     setCentralWidget(centralview);
-   
+
     createActions();
     createMenus();
-   
+
     connect(queryfield, SIGNAL(textChanged(const QString&)),
         this, SLOT(query(const QString&)));
     connect(toggleindexing, SIGNAL(clicked()),
@@ -121,25 +144,25 @@ SimpleSearchGui::SimpleSearchGui (QWidget * parent, Qt::WFlags flags)
         this, SLOT(removeDirectory()));
     queryfield->setFocus(Qt::ActiveWindowFocusReason);
 
-    socketfile = getenv("HOME");
-    socketfile += "/.strigi/socket";
+    connect(&asyncstrigi,SIGNAL(statusUpdated(const QMap<QString, QString>& )),
+        this, SLOT(updateStatus(const QMap<QString, QString>& )));
+    connect(tabs->getSearchView(), SIGNAL(gotHits(const QString&)),
+        histogram, SLOT(setQuery(const QString&)));
+    connect(fieldnames, SIGNAL(currentIndexChanged(const QString&)),
+        histogram, SLOT(setFieldName(const QString&)));
 
-    connect (&strigi, SIGNAL (gotDaemonStatus( const QMap< QString, QString >& )), this, SLOT (updateStatus( const QMap< QString, QString >& )));
-    connect (&strigi, SIGNAL (socketError(Qt4StrigiClient::Mode)), this, SLOT (socketError(Qt4StrigiClient::Mode)));
-    
     QTimer *timer = new QTimer(this);
-    connect(timer, SIGNAL(timeout()), &strigi, SLOT(getDaemonStatus()));
+    connect(timer, SIGNAL(timeout()), this, SLOT(updateStatus()));
     timer->start(2000);
-    QMap<QString,QString> emptyMap;
-    updateStatus(emptyMap);
+    asyncstrigi.updateStatus();
 }
 void
 SimpleSearchGui::createMenus() {
     fileMenu = menuBar()->addMenu(tr("&File"));
     fileMenu->addAction(fileExitAct);
-   
+
     editMenu = menuBar()->addMenu(tr("&Edit"));
-    editMenu->addAction(editPreferenceAct);
+    editMenu->addAction(editFiltersAct);
     editMenu->addAction(editListIndexedFilesAct);
 }
 void
@@ -148,48 +171,50 @@ SimpleSearchGui::createActions() {
     fileExitAct->setShortcut(tr("Ctrl+Q"));
     fileExitAct->setStatusTip(tr("Quit the program"));
     connect(fileExitAct, SIGNAL(triggered()), this, SLOT(close()));
-   
-    editPreferenceAct = new QAction(tr("Edit Preferences"), this);
-    editPreferenceAct->setStatusTip(tr("Edit program preferences"));
-    connect(editPreferenceAct, SIGNAL(triggered()), this, SLOT(editPreferences()));
-    
+
+    editFiltersAct = new QAction(tr("Edit Filters"), this);
+    editFiltersAct->setStatusTip(tr("Edit filename filters"));
+    connect(editFiltersAct, SIGNAL(triggered()), this, SLOT(editFilters()));
+
     editListIndexedFilesAct = new QAction(tr("List indexed files"), this);
     editListIndexedFilesAct->setStatusTip(tr("Show files indexed by strigi"));
     connect(editListIndexedFilesAct, SIGNAL(triggered()), this, SLOT(editListIndexedFiles()));
 }
 void
 SimpleSearchGui::query(const QString& item) {
-    if (item.length()) {
-        tabs->setQuery(item);
-    }
     QString query = item.trimmed();
     if (query.length() == 0) {
+        tabs->setQuery(QString());
+        asyncstrigi.updateStatus();
         mainview->setCurrentIndex(1);
     } else {
         mainview->setCurrentIndex(0);
+        tabs->setQuery(query);
     }
 }
 void
-SimpleSearchGui::updateStatus(const QMap< QString, QString >& s) {
-    static bool first = true;
+SimpleSearchGui::updateStatus() {
+    if (statusview->isVisible()) {
+        asyncstrigi.updateStatus();
+    }
+}
+void
+SimpleSearchGui::updateStatus(const QMap<QString, QString>& s) {
+//    static bool first = true;
     static bool attemptedstart = false;
-    if (!first && !statusview->isVisible()) return;
-    first = false;
+//    if (!first && !statusview->isVisible()) return;
+//    first = false;
     QMap<QString, QString> status (s);
     if (status.size() == 0) {
         running = false;
+        editFiltersAct->setEnabled(false);
         editListIndexedFilesAct->setEnabled(false);
-        /*if (!attemptedstart) {
-            status["Status"] = "Starting daemon";
-            startDaemon();
-            attemptedstart = true;
-        } else {*/
-            status["Status"] = "Daemon is not running";
-        //}
+        status["Status"] = "Daemon is not running";
     } else {
         attemptedstart = true;
         starting = false;
         running = true;
+        editFiltersAct->setEnabled(true);
         editListIndexedFilesAct->setEnabled(true);
         if (indexeddirs->count() == 0) {
             updateDirectories();
@@ -209,7 +234,7 @@ SimpleSearchGui::updateStatus(const QMap< QString, QString >& s) {
         indexing = idxng;
         toggleindexing->setText((indexing)?"stop indexing":"start indexing");
     }
-   
+
     QMap<QString,QString>::const_iterator i;
     QString text;
     for (i = status.begin(); i != status.end(); ++i) {
@@ -221,21 +246,6 @@ SimpleSearchGui::updateStatus(const QMap< QString, QString >& s) {
     statusview->setText(text);
 }
 void
-SimpleSearchGui::socketError(Qt4StrigiClient::Mode mode)
-{
-    switch (mode)
-    {
-        case Qt4StrigiClient::GetDaemonStatus:
-        {
-            QMap<QString, QString> emptyMap;
-            updateStatus (emptyMap);
-            break;
-        }
-        default:
-            break;
-    }
-}
-void
 SimpleSearchGui::startDaemon() {
     toggledaemon->setEnabled(false);
     starting = true;
@@ -262,9 +272,7 @@ SimpleSearchGui::startDaemon() {
 void
 SimpleSearchGui::toggleDaemon() {
     if (running) {
-        SocketClient client;
-        client.setSocketName(socketfile.c_str());
-        client.stopDaemon();
+        strigi.stopDaemon();
         indexeddirs->clear();
     } else {
         startDaemon();
@@ -272,12 +280,10 @@ SimpleSearchGui::toggleDaemon() {
 }
 void
 SimpleSearchGui::toggleIndexing() {
-    SocketClient client;
-    client.setSocketName(socketfile.c_str());
     if (indexing) {
-        client.stopIndexing();
+        strigi.stopIndexing();
     } else {
-        client.startIndexing();
+        strigi.startIndexing();
     }
 }
 void
@@ -300,57 +306,46 @@ SimpleSearchGui::addDirectory() {
 }
 void
 SimpleSearchGui::removeDirectory() {
-    int i = indexeddirs->currentRow();
-    if (i == -1) return;
-    indexeddirs->takeItem(i);
+    QList<QListWidgetItem*> items = indexeddirs->selectedItems();
+    
+    if (items.size() == 0)
+        return;
+
+    for (QList<QListWidgetItem*>::iterator iter = items.begin(); iter != items.end(); iter++)
+    {
+        int row = indexeddirs->row (*iter);
+        indexeddirs->takeItem (row);
+    }
     setDirectories();
 }
 void
 SimpleSearchGui::setDirectories() {
-    set<string> s;
+    QStringList s;
     for (int i=0; i<indexeddirs->count(); ++i) {
         QString text = indexeddirs->item(i)->text();
-        s.insert((const char*)text.toUtf8());
+        s.append(text);
     }
-    SocketClient client;
-    client.setSocketName(socketfile.c_str());
-    client.setIndexedDirectories(s);
+    strigi.setIndexedDirectories(s);
     updateDirectories();
 }
 void
 SimpleSearchGui::updateDirectories() {
     indexeddirs->clear();
-    SocketClient client;
-    client.setSocketName(socketfile.c_str());
-    set<string> s = client.getIndexedDirectories();
-    indexeddirs->clear();
-    set<string>::const_iterator i;
-    for (i = s.begin(); i != s.end(); ++i) {
-        QString dir(QString::fromUtf8(i->c_str()));
-        indexeddirs->addItem(dir);
+    indexeddirs->addItems(strigi.getIndexedDirectories());
+}
+void
+SimpleSearchGui::editFilters() {
+    QList<QPair<bool,QString> > filters;
+    filters = strigi.getFilters();
+
+    DlgFilters dlg(filters);
+    if (dlg.exec() && filters != dlg.getFilters()) {
+        strigi.setFilters(dlg.getFilters());
     }
 }
 void
-SimpleSearchGui::editPreferences() {
-    SocketClient client;
-    client.setSocketName(socketfile.c_str());
-    multimap<int,string> rules = client.getFilteringRules();
-   
-    DlgPreferences* dlg = new DlgPreferences (running, &rules);
-    dlg->exec();
-   
-    delete dlg;
-    
-    //update filtering rules
-    client.setFilteringRules( rules);
-}
-void
 SimpleSearchGui::editListIndexedFiles() {
-    SocketClient client;
-    client.setSocketName(socketfile.c_str());
-    set<string> files = client.getIndexedFiles();
-   
-    DlgListIndexedFiles dlg (files);
+    QStringList files = strigi.getIndexedFiles();
+    DlgListIndexedFiles dlg(files);
     dlg.exec();
 }
-
