@@ -21,8 +21,8 @@
 #define SIMPLESEARCHGUI_H
 
 #include <QtGui/QMainWindow>
-
-#include "qt4strigiclient.h"
+#include "strigiclient.h"
+#include "strigiasyncclient.h"
 
 class QLineEdit;
 class QListWidget;
@@ -35,6 +35,7 @@ class QWidget;
 class QMenu;
 class QAction;
 class SearchTabs;
+class Histogram;
 
 class SimpleSearchGui : public QMainWindow {
 Q_OBJECT
@@ -42,7 +43,6 @@ private:
     bool starting;
     bool indexing;
     bool running;
-    std::string socketfile;
     QStackedWidget* mainview;
     SearchTabs* tabs;
     QLabel* statusview;
@@ -53,30 +53,32 @@ private:
     QPushButton* toggleindexing;
     QPushButton* toggledaemon;
     QComboBox* backendsList;
+    QComboBox* fieldnames;
     QWidget* centralview;
     QMenu *fileMenu;
     QMenu *editMenu;
     QAction *fileExitAct;
-    QAction *editPreferenceAct;
+    QAction *editFiltersAct;
     QAction *editListIndexedFilesAct;
-    Qt4StrigiClient strigi;
-   
+    StrigiAsyncClient asyncstrigi;
+    StrigiClient strigi;
+    Histogram* histogram;
+
     void startDaemon();
     void setDirectories();
     void updateDirectories();
     void createMenus();
     void createActions();
 private slots:
-    void updateStatus( const QMap< QString, QString >& );
+    void updateStatus();
+    void updateStatus(const QMap<QString, QString>& s);
     void toggleDaemon();
     void toggleIndexing();
     void query(const QString&);
     void addDirectory();
     void removeDirectory();
-    void editPreferences();
+    void editFilters();
     void editListIndexedFiles();
-    void socketError(Qt4StrigiClient::Mode);
-
 public:
     SimpleSearchGui(QWidget * parent = 0, Qt::WFlags flags = 0);
 };
