@@ -21,16 +21,16 @@
 #include "indexer.h"
 #include "filelister.h"
 #include "filereader.h"
-#include "filtermanager.h"
 
 using namespace std;
 
 Indexer *Indexer::workingIndexer;
 
-Indexer::Indexer(const char *indexdir, FilterManager* filtermanager) :m_indexdir(indexdir),
-        m_manager(indexdir), m_indexer(m_manager.getIndexWriter())
+Indexer::Indexer(const char *indexdir, jstreams::IndexerConfiguration& ic)
+        : m_indexdir(indexdir), m_manager(indexdir),
+          m_indexer(*m_manager.getIndexWriter(), ic)
 {
-    m_lister = new FileLister (filtermanager);
+    m_lister = new FileLister(ic);
 }
 Indexer::~Indexer() {
     delete m_lister;
@@ -50,11 +50,10 @@ Indexer::index(const char *dir) {
         m_lister->listFiles(dir);
     }
 }
-bool
+void
 Indexer::addFileCallback(const char* path, uint dirlen, uint len,
         time_t mtime) {
     workingIndexer->doFile(path);
-    return true;
 }
 void
 Indexer::doFile(const std::string &filepath) {
