@@ -25,7 +25,6 @@
 #include "streamindexer.h"
 
 class FileLister;
-class FilterManager;
 
 class Indexer {
 private:
@@ -34,12 +33,12 @@ private:
     SqliteIndexManager m_manager;
     jstreams::StreamIndexer m_indexer;
 
-    static bool addFileCallback(const char* path, uint dirlen, uint len,
+    static void addFileCallback(const char* path, uint dirlen, uint len,
         time_t mtime);
     static Indexer *workingIndexer;
     void doFile(const std::string &filepath);
 public:
-    explicit Indexer(const char *indexdir, FilterManager* filtermanager);
+    Indexer(const char *indexdir, jstreams::IndexerConfiguration&);
     ~Indexer();
     void index(const char *dir);
 };
