@@ -19,7 +19,7 @@
  */
 #include "jstreamsconfig.h"
 #include "indexer.h"
-#include "filtermanager.h"
+#include "indexerconfiguration.h"
 
 int
 main(int argc, char **argv) {
@@ -29,9 +29,9 @@ main(int argc, char **argv) {
     }
     std::string file = argv[1];
     file += "/sqlite.db";
-    
-    FilterManager filtermanager;
-    Indexer indexer(file.c_str(), &filtermanager);
+
+    jstreams::IndexerConfiguration ic;
+    Indexer indexer(file.c_str(), ic);
     indexer.index(argv[2]);
     return 0;
 }
