@@ -29,10 +29,10 @@ SqliteIndexReader::SqliteIndexReader(SqliteIndexManager* m) :manager(m) {
 SqliteIndexReader::~SqliteIndexReader() {
 }
 set<string>
-split(const std::string& q) {
+split(const string& q) {
     set<string> terms;
-    uint pos = q.find(' ');
-    uint offset = 0;
+    string::size_type pos = q.find(' ');
+    string::size_type offset = 0;
     while (pos != string::npos) {
         if (pos-offset > 0) {
             terms.insert(q.substr(offset, pos-offset));
@@ -115,7 +115,7 @@ SqliteIndexReader::query(const jstreams::Query& query) {
     }
     // split up in terms
     set<string> terms = split(q);
-    std::vector<IndexedDocument> results;
+    vector<IndexedDocument> results;
     if (terms.size() == 0) return results;
     string pathfilter;
     set<string>::iterator i = terms.begin();
@@ -220,10 +220,30 @@ SqliteIndexReader::countDocuments() {
     return count;
 }
 int64_t
-SqliteIndexReader::getDocumentId(const std::string& uri) {
+SqliteIndexReader::getDocumentId(const string& uri) {
     return -1;
 }
 time_t
 SqliteIndexReader::getMTime(int64_t docid) {
     return 0;
 }
+vector<pair<string,uint32_t> >
+SqliteIndexReader::getHistogram( const string& query, const string& fieldname,
+            const string& labeltype) {
+    return vector<pair<string,uint32_t> >();
+}
+vector<string>
+SqliteIndexReader::getFieldNames() {
+    return vector<string>();
+}
+int32_t
+SqliteIndexReader::countKeywords(const string& keywordprefix,
+        const vector<string>& fieldnames) {
+    return -1;
+}
+vector<string>
+SqliteIndexReader::getKeywords(const string& keywordmatch,
+        const vector<string>& fieldnames, uint32_t max, uint32_t offset) {
+    vector<string> k;
+    return k;
+}
