@@ -26,9 +26,19 @@
 class BZ2EndAnalyzer : public jstreams::StreamEndAnalyzer {
 public:
     bool checkHeader(const char* header, int32_t headersize) const;
-    char analyze(std::string filename, jstreams::InputStream *in, int depth,
-        jstreams::StreamIndexer *indexer, jstreams::Indexable*);
+    char analyze(jstreams::Indexable& idx, jstreams::InputStream* in);
     const char* getName() const { return "BZ2EndAnalyzer"; }
 };
 
+class BZ2EndAnalyzerFactory : public jstreams::StreamEndAnalyzerFactory {
+public:
+    const char* getName() const {
+        return "BZ2EndAnalyzer";
+    }
+    jstreams::StreamEndAnalyzer* newInstance() const {
+        return new BZ2EndAnalyzer();
+    }
+    bool analyzesSubStreams() const { return true; }
+};
+
 #endif
