@@ -35,7 +35,18 @@ public:
     ~DigestThroughAnalyzer();
     void setIndexable(jstreams::Indexable*);
     jstreams::InputStream *connectInputStream(jstreams::InputStream *in);
-    bool isReadyWithStream() { return false; }
+    bool isReadyWithStream();
+};
+
+class DigestThroughAnalyzerFactory
+        : public jstreams::StreamThroughAnalyzerFactory {
+private:
+    const char* getName() const {
+        return "DigestThroughAnalyzer";
+    }
+    jstreams::StreamThroughAnalyzer* newInstance() const {
+        return new DigestThroughAnalyzer();
+    }
 };
 
 #endif
