@@ -19,7 +19,7 @@
  */
 #include "jstreamsconfig.h"
 #include "filelister.h"
-#include "filtermanager.h"
+#include "indexerconfiguration.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <stdlib.h>
@@ -34,41 +34,48 @@
 #endif
 
 using namespace std;
+using namespace jstreams;
 
 string fixPath (string path)
 {
-    string temp (path);
-    
-    char separator;
-    
+	if ( path.c_str() == NULL || path.length() == 0 )
+		return "";
+
+    string temp(path);
+
 #ifdef HAVE_WINDOWS_H
-    separator = '\\';
-#else
-    separator = '/';
+	size_t l= temp.length();
+	char* t = (char*)temp.c_str();
+	for (size_t i=0;i<l;i++){
+		if ( t[i] == '\\' )
+			t[i] = '/';
+	}
+	temp[0] = tolower(temp.at(0));
 #endif
 
+    char separator = '/';
+
     if (temp[temp.length() - 1 ] != separator)
         temp += separator;
-    
+
     return temp;
 }
 
-FileLister::FileLister(FilterManager* filtermanager) {
+FileLister::FileLister(IndexerConfiguration& ic) :m_config(ic) {
     m_fileCallback = 0;
     m_dirCallback = 0;
     path = 0;
     length = 0;
-    m_filterManager = filtermanager;
 }
 FileLister::~FileLister() {
     if (length) {
         free(path);
     }
 }
-
 void
 FileLister::listFiles(const char *dir, time_t oldestdate) {
     if (m_fileCallback == 0) return;
+    printf("listFiles %s\n", dir);
     m_oldestdate = oldestdate;
     int len = strlen(dir);
     resize(len+2);
@@ -78,6 +85,9 @@ FileLister::listFiles(const char *dir, time_t oldestdate) {
         strcpy(path+len, "/");
         len++;
     }
+#ifdef WIN32
+    path[0] = tolower(path[0]);
+#endif
     walk_directory(len);
 }
 char*
@@ -91,36 +101,40 @@ FileLister::resize(uint len) {
 /**
  * Walk through a directory. The directory name must end in a '/'.
  **/
-bool
+void
 FileLister::walk_directory(uint len) {
     //bool expandedPath = false;
     DIR *dir;
     struct dirent *subdir;
     struct stat dirstat;
-    
-    if ((m_filterManager != NULL) && (m_filterManager->findMatch( path, len)))
-        return true; 
-    else if (m_filterManager == NULL)
-        printf ("m_filtermanager is NULL!!\n");
-    
-#ifndef WIN32
-    // call dir function callback, actually there's only inotify dir callback
-    if (m_dirCallback != 0)
-        m_dirCallback (path, len);
-#else// remove the trailing '/' on windows machines before the call to opendir(),
+
+#ifdef WIN32
+    // windows opendir expects no trailing slash on the end of directories...
+    // remove the trailing '/' on windows machines before the call to opendir(),
     // but do not strip off the trailing slash from windows c:/
     if ( len > 3) {
-        path[len-1] = '\0';
+        while(path[len-1]=='/' || path[len-1]=='\\') {
+            len--;
+            path[len] = '\0';
+        }
     }
 #endif
 
+    // call dir function callback, actually there's only inotify dir callback
+    if (m_dirCallback != 0)
+        m_dirCallback(path, len);
+
     // open the directory
     dir = opendir(path);
     if (dir == 0) {
-        return true;
+        return;
     }
 #ifdef WIN32
-    path[len-1] = '/';
+    //add the trailing slash back on
+    if ( len > 3) {
+        strcat(path, "/");
+        len++;
+    }
 #endif
 
     subdir = readdir(dir);
@@ -136,23 +150,21 @@ FileLister::walk_directory(uint len) {
             }
         }
 
-        uint l = len+strlen(subdir->d_name);
+        uint l = len + strlen(subdir->d_name);
         path = resize(l+1);
         strcpy(path+len, subdir->d_name);
         // check if the file is a normal file (use lstat, NOT stat)
         if (lstat(path, &dirstat) == 0) {
-            bool c = true;
-            if ( S_ISREG(dirstat.st_mode) && dirstat.st_mtime >= m_oldestdate) {
-                if ((m_filterManager != NULL) && (!m_filterManager->findMatch( path, l)))
-                    c = m_fileCallback(path, len, l, dirstat.st_mtime);
-            } else if ( dirstat.st_mode & S_IFDIR) {
+            if (S_ISREG(dirstat.st_mode) && dirstat.st_mtime >= m_oldestdate) {
+                if (m_config.indexFile(path, path+len)) {
+                    m_fileCallback(path, len, l, dirstat.st_mtime);
+                }
+            } else if (dirstat.st_mode & S_IFDIR
+                    && m_config.indexDir(path, path+len)) {
+                // append a '/' to the path
                 strcpy(path+l, "/");
-                c = walk_directory(l+1);
+                walk_directory(l+1);
             }
-            if (!c) break;
-/*        } else {
-            fprintf(stderr, "Could not stat '%s': %s\n", cwd,
-                strerror(errno));*/
         }
 
         subdir = readdir(dir);
@@ -162,5 +174,4 @@ FileLister::walk_directory(uint len) {
     closedir(dir);
     // go back to where we came from
     //chdir("..");
-    return true;
 }
