@@ -35,36 +35,39 @@
 #include <sys/types.h>
 #include <string>
 
-class FilterManager;
+namespace jstreams {
+    class IndexerConfiguration;
+}
 
 class FileLister {
 private:
     char* path;
     uint length;
     time_t m_oldestdate;
-    bool (*m_fileCallback)(const char* fullpath, uint dirlen, uint len,
+    void (*m_fileCallback)(const char* fullpath, uint dirlen, uint len,
         time_t mtime);
     void (*m_dirCallback)(const char* fullpath,  uint len);
 
     char* resize(uint len);
-    bool walk_directory(uint len);
-    
-    FilterManager* m_filterManager;
+    void walk_directory(uint len);
+
+    jstreams::IndexerConfiguration& m_config;
 public:
-    explicit FileLister(FilterManager* filtermanager);
+    explicit FileLister(jstreams::IndexerConfiguration& ic);
     ~FileLister();
     /**
      * Specify the callback function that reports the files found.
          **/
-    void setFileCallbackFunction(bool (*callback)(const char* fullpath,
+    void setFileCallbackFunction(void (*callback)(const char* fullpath,
             uint dirlen, uint len, time_t mtime)) {
         m_fileCallback = callback;
     }
-   
-    void setDirCallbackFunction(void (*callback)(const char* fullpath , uint len)) {
-                                 m_dirCallback = callback;
+
+    void setDirCallbackFunction(
+            void (*callback)(const char* fullpath, uint len)) {
+        m_dirCallback = callback;
     }
-   
+
     /**
      * List all the files in directory dir that have been modified more
      * recently then oldestdate.
