@@ -19,37 +19,38 @@
  */
 #include "jstreamsconfig.h"
 #include "helperendanalyzer.h"
-#include "streamindexer.h"
 #include "processinputstream.h"
 #include "textendanalyzer.h"
+#include "indexable.h"
 #include <fcntl.h>
 #include <errno.h>
 #include <sys/stat.h>
+#include <unistd.h>
 using namespace jstreams;
 using namespace std;
 
 
 #ifdef WIN32
     #include <fcntl.h>
-    #define _S_IREAD 256
-    #define _S_IWRITE 128
     int mkstemp(char *tmpl)
     {
        mktemp(tmpl);
        return open(tmpl,O_RDWR|O_BINARY|O_CREAT|O_EXCL|_O_SHORT_LIVED, _S_IREAD|_S_IWRITE);
     }
+#else
+    #include <unistd.h>
 #endif
 
 class HelperProgramConfig::HelperRecord {
 public:
-    const char* magic;
+    const unsigned char* magic;
     ssize_t magicsize;
     vector<string> arguments;
     bool readfromstdin;
 };
 
 HelperProgramConfig::HelperProgramConfig() {
-    static const char wordmagic[] = {0xd0,0xcf,0x11,0xe0,0xa1,0xb1,0x1a,0xe1,
+    static const unsigned char wordmagic[] = {0xd0,0xcf,0x11,0xe0,0xa1,0xb1,0x1a,0xe1,
         0,0,0,0,0,0,0,0};
 
     // make a vector with all the paths
@@ -68,9 +69,9 @@ HelperProgramConfig::HelperProgramConfig() {
     }
 
     string exepath = getPath("pdftotext", paths);
-    if (exepath.length()) { 
+    if (exepath.length()) {
         HelperRecord* h = new HelperRecord();
-        h->magic = "%PDF-1.";
+        h->magic = (unsigned char*)"%PDF-1.";
         h->magicsize = 7;
         h->arguments.push_back(exepath);
         h->arguments.push_back("%s");
@@ -130,8 +131,7 @@ HelperEndAnalyzer::checkHeader(const char* header, int32_t headersize) const {
     return helperconfig.findHelper(header, headersize) != 0;
 }
 char
-HelperEndAnalyzer::analyze(std::string filename, jstreams::InputStream *in,
-        int depth, StreamIndexer *indexer, Indexable* i) {
+HelperEndAnalyzer::analyze(jstreams::Indexable& idx, jstreams::InputStream* in){
     char state = -1;
     const char* b;
     int32_t nread = in->read(b, 1024, 0);
@@ -141,16 +141,16 @@ HelperEndAnalyzer::analyze(std::string filename, jstreams::InputStream *in,
             = helperconfig.findHelper(b, nread);
         if (h) {
 //            fprintf(stderr, "calling %s on %s\n", h->arguments[0].c_str(),
-//                filename.c_str());
+//                idx.getPath().c_str());
             if (h->readfromstdin) {
                 ProcessInputStream pis(h->arguments, in);
                 TextEndAnalyzer t;
-                state = t.analyze(filename, &pis, depth, indexer, i);
+                state = t.analyze(idx, &pis);
             } else {
                 string filepath;
-                bool fileisondisk = checkForFile(depth, filename);
+                bool fileisondisk = checkForFile(idx);
                 if (fileisondisk) {
-                    filepath = filename;
+                    filepath = idx.getPath();
                 } else {
                     filepath = writeToTempFile(in);
                 }
@@ -162,16 +162,16 @@ HelperEndAnalyzer::analyze(std::string filename, jstreams::InputStream *in,
                 }
                 ProcessInputStream pis(args);
                 TextEndAnalyzer t;
-                state = t.analyze(filename, &pis, depth, indexer, i);
+                state = t.analyze(idx, &pis);
                 if (!fileisondisk) {
                     unlink(filepath.c_str());
                 }
             }
         }
     }
-    if (in->getStatus() != Eof) {
+    if (in->getStatus() == Error) {
         error = in->getError();
-        state = -1;
+        state = Error;
     }
     return state;
 }
@@ -197,14 +197,14 @@ HelperEndAnalyzer::writeToTempFile(jstreams::InputStream *in) const {
             nread -= n;
         } while (nread > 0);
         nread = in->read(b, 1, 0);
-    } 
+    }
     close(fd);
     return filepath;
 }
 bool
-HelperEndAnalyzer::checkForFile(int depth, const std::string& filename) {
-    if (depth > 0) return false;
+HelperEndAnalyzer::checkForFile(const Indexable& idx) const {
+    if (idx.getDepth() > 0) return false;
     struct stat s;
-    if (stat(filename.c_str(), &s)) return false;
+    if (stat(idx.getPath().c_str(), &s)) return false;
     return true;
 }
