@@ -22,6 +22,10 @@
 
 #include <map>
 #include <string>
+#ifdef HAVE_STDINT_H
+ #include <stdint.h>
+#endif
+#include "jstreamsconfig.h"
 
 namespace jstreams {
 
