@@ -100,6 +100,28 @@ public:
      *         document in the index, 0 is returned.
      **/
     virtual time_t getMTime(int64_t docid) = 0;
+    /**
+     * Retrieve the fieldnames in use in this index.
+     **/
+    virtual std::vector<std::string> getFieldNames() = 0;
+    /**
+     * Retrieve a histogram of the different values that are in this query.
+     **/
+    virtual std::vector<std::pair<std::string,uint32_t> > getHistogram(
+            const std::string& query, const std::string& fieldname,
+            const std::string& labeltype) = 0;
+    /**
+     *
+     **/
+    virtual int32_t countKeywords(const std::string& keywordprefix,
+        const std::vector<std::string>& fieldnames) = 0;
+    /**
+     *
+     **/
+    virtual std::vector<std::string> getKeywords(
+        const std::string& keywordmatch,
+        const std::vector<std::string>& fieldnames,
+        uint32_t max, uint32_t offset) = 0;
 };
 
 }
