@@ -20,8 +20,8 @@
 #include "jstreamsconfig.h"
 #include "rpmendanalyzer.h"
 #include "rpminputstream.h"
-#include "streamindexer.h"
 #include "subinputstream.h"
+#include "indexable.h"
 using namespace jstreams;
 
 bool
@@ -29,8 +29,7 @@ RpmEndAnalyzer::checkHeader(const char* header, int32_t headersize) const {
     return RpmInputStream::checkHeader(header, headersize);
 }
 char
-RpmEndAnalyzer::analyze(std::string filename, InputStream *in,
-        int depth, StreamIndexer *indexer, jstreams::Indexable*) {
+RpmEndAnalyzer::analyze(jstreams::Indexable& idx, jstreams::InputStream* in) {
     RpmInputStream rpm(in);
     InputStream *s = rpm.nextEntry();
     if (rpm.getStatus()) {
@@ -38,9 +37,8 @@ RpmEndAnalyzer::analyze(std::string filename, InputStream *in,
 //        exit(1);
     }
     while (s) {
-        std::string file = filename+'/';
-        file += rpm.getEntryInfo().filename;
-        indexer->analyze(file, rpm.getEntryInfo().mtime, s, depth);
+        idx.indexChild(rpm.getEntryInfo().filename, rpm.getEntryInfo().mtime,
+            *s);
         s = rpm.nextEntry();
     }
     if (rpm.getStatus() == jstreams::Error) {
