@@ -25,9 +25,19 @@
 class RpmEndAnalyzer : public jstreams::StreamEndAnalyzer {
 public:
     bool checkHeader(const char* header, int32_t headersize) const;
-    char analyze(std::string filename, jstreams::InputStream *in, int depth,
-        jstreams::StreamIndexer *indexer, jstreams::Indexable*);
+    char analyze(jstreams::Indexable& idx, jstreams::InputStream* in);
     const char* getName() const { return "RpmEndAnalyzer"; }
 };
 
+class RpmEndAnalyzerFactory : public jstreams::StreamEndAnalyzerFactory {
+public:
+    const char* getName() const {
+        return "RpmEndAnalyzer";
+    }
+    jstreams::StreamEndAnalyzer* newInstance() const {
+        return new RpmEndAnalyzer();
+    }
+    bool analyzesSubStreams() const { return true; }
+};
+
 #endif
