@@ -30,9 +30,18 @@ public:
     SaxEndAnalyzer();
     ~SaxEndAnalyzer();
     bool checkHeader(const char* header, int32_t headersize) const;
-    char analyze(std::string filename, jstreams::InputStream *in, int depth,
-        jstreams::StreamIndexer *indexer, jstreams::Indexable*);
+    char analyze(jstreams::Indexable& idx, jstreams::InputStream* in);
     const char* getName() const { return "SaxEndAnalyzer"; }
 };
 
+class SaxEndAnalyzerFactory : public jstreams::StreamEndAnalyzerFactory {
+public:
+    const char* getName() const {
+        return "SaxEndAnalyzer";
+    }
+    jstreams::StreamEndAnalyzer* newInstance() const {
+        return new SaxEndAnalyzer();
+    }
+};
+
 #endif
