@@ -34,31 +34,46 @@
 #include "mailendanalyzer.h"
 #include "helperendanalyzer.h"
 #include "id3v2throughanalyzer.h"
+#include "oggthroughanalyzer.h"
 #include "digestthroughanalyzer.h"
-#include "pluginthroughanalyzer.h"
-#include "pluginendanalyzer.h"
-#include "indexwriter.h"
+#include "indexable.h"
+#include "indexerconfiguration.h"
 #include "textutils.h"
 #include <sys/stat.h>
+#ifdef WIN32
+ #include "ifilterendanalyzer.h"
+#endif
 
 using namespace std;
 using namespace jstreams;
 
-StreamIndexer::StreamIndexer(IndexWriter* w) :writer(w) {
-   
+StreamIndexer::StreamIndexer(IndexWriter& w, IndexerConfiguration& c)
+        :writer(w), conf(c) {
+
     moduleLoader.loadPlugins("/usr/local/lib/strigi");
     moduleLoader.loadPlugins("/usr/lib/strigi");
     moduleLoader.loadPlugins("/lib/strigi");
-
-    // todo: remove this
+    
+        // todo: remove this
     moduleLoader.loadPlugins("D:\\clients\\strigi_svn\\win\\out\\Debug");
-    if ( getenv("HOME") != NULL ){
-        string homedir = getenv("HOME");
-        homedir += "/testinstall/lib/strigi";
+        if ( getenv("HOME") != NULL ){
+            string homedir = getenv("HOME");
+            homedir += "/testinstall/lib/strigi";
         moduleLoader.loadPlugins(homedir.c_str());
-    }
+        }
+    initializeThroughFactories();
+    initializeEndFactories();
 }
 StreamIndexer::~StreamIndexer() {
+    // delete all factories
+    std::vector<StreamThroughAnalyzerFactory*>::iterator ta;
+    for (ta = throughfactories.begin(); ta != throughfactories.end(); ++ta) {
+        delete *ta;
+    }
+    std::vector<StreamEndAnalyzerFactory*>::iterator ea;
+    for (ea = endfactories.begin(); ea != endfactories.end(); ++ea) {
+        delete *ea;
+    }
     // delete the through analyzers and end analyzers
     std::vector<std::vector<StreamThroughAnalyzer*> >::iterator tIter;
     for (tIter = through.begin(); tIter != through.end(); ++tIter) {
@@ -76,12 +91,12 @@ StreamIndexer::~StreamIndexer() {
     }
 }
 char
-StreamIndexer::indexFile(const char *filepath) {
+StreamIndexer::indexFile(const char *filepath, IndexerConfiguration* ic) {
     std::string path(filepath);
     return indexFile(path);
 }
 char
-StreamIndexer::indexFile(const std::string& filepath) {
+StreamIndexer::indexFile(const std::string& filepath){
     if (!checkUtf8(filepath.c_str())) {
         return 1;
     }
@@ -90,74 +105,104 @@ StreamIndexer::indexFile(const std::string& filepath) {
     FileInputStream file(filepath.c_str());
     // ensure a decent buffer size
     //file.mark(65530);
-    return analyze(filepath, s.st_mtime, &file, 0);
+    string name;
+    Indexable indexable(filepath, s.st_mtime, writer, *this);
+    return indexable.index(file);
+}
+void
+StreamIndexer::addFactory(StreamThroughAnalyzerFactory* f) {
+    if (conf.useFactory(f)) {
+        throughfactories.push_back(f);
+    } else {
+        delete f;
+    }
+}
+void
+StreamIndexer::initializeThroughFactories() {
+    list<StreamThroughAnalyzerFactory*> plugins
+        = moduleLoader.getStreamThroughAnalyzerFactories();
+    list<StreamThroughAnalyzerFactory*>::iterator i;
+    for (i = plugins.begin(); i != plugins.end(); ++i) {
+        addFactory(*i);
+    }
+    //addFactory(new DigestThroughAnalyzerFactory());
+    addFactory(new ID3V2ThroughAnalyzerFactory());
+    addFactory(new OggThroughAnalyzerFactory());
+}
+void
+StreamIndexer::addFactory(StreamEndAnalyzerFactory* f) {
+    if (conf.useFactory(f)) {
+        endfactories.push_back(f);
+    } else {
+        delete f;
+    }
+}
+/**
+ * Instantiate factories for all analyzers.
+ **/
+void
+StreamIndexer::initializeEndFactories() {
+    list<StreamEndAnalyzerFactory*> plugins
+        = moduleLoader.getStreamEndAnalyzerFactories();
+    list<StreamEndAnalyzerFactory*>::iterator i;
+    for (i = plugins.begin(); i != plugins.end(); ++i) {
+        addFactory(*i);
+    }
+    addFactory(new BZ2EndAnalyzerFactory());
+    addFactory(new GZipEndAnalyzerFactory());
+    addFactory(new TarEndAnalyzerFactory());
+    addFactory(new ArEndAnalyzerFactory());
+    addFactory(new MailEndAnalyzerFactory());
+    addFactory(new ZipEndAnalyzerFactory());
+    addFactory(new RpmEndAnalyzerFactory());
+    addFactory(new PngEndAnalyzerFactory());
+//    addFactory(new PdfEndAnalyzerFactory());
+#ifdef WIN32
+    addFactory(new IFilterEndAnalyzerFactory());
+#else
+	//temporary only, i just haven't got expat.h working yet
+	addFactory(new SaxEndAnalyzerFactory());
+#endif
+    addFactory(new HelperEndAnalyzerFactory());
+    addFactory(new TextEndAnalyzerFactory());
 }
 void
 StreamIndexer::addThroughAnalyzers() {
     through.resize(through.size()+1);
     std::vector<std::vector<StreamThroughAnalyzer*> >::reverse_iterator tIter;
     tIter = through.rbegin();
-    StreamThroughAnalyzer* ana = new DigestThroughAnalyzer();
-    tIter->push_back(ana);
-    ana = new PluginThroughAnalyzer(&moduleLoader);
-    tIter->push_back(ana);
-    ana = new ID3V2ThroughAnalyzer();
-    tIter->push_back(ana);
+    std::vector<StreamThroughAnalyzerFactory*>::iterator ta;
+    for (ta = throughfactories.begin(); ta != throughfactories.end(); ++ta) {
+        tIter->push_back((*ta)->newInstance());
+    }
 }
 void
 StreamIndexer::addEndAnalyzers() {
     end.resize(end.size()+1);
     std::vector<std::vector<StreamEndAnalyzer*> >::reverse_iterator eIter;
     eIter = end.rbegin();
-    StreamEndAnalyzer* ana = new BZ2EndAnalyzer();
-    eIter->push_back(ana);
-    ana = new GZipEndAnalyzer();
-    eIter->push_back(ana);
-    ana = new TarEndAnalyzer();
-    eIter->push_back(ana);
-    ana = new ArEndAnalyzer();
-    eIter->push_back(ana);
-    ana = new MailEndAnalyzer();
-    eIter->push_back(ana);
-    ana = new ZipEndAnalyzer();
-    eIter->push_back(ana);
-    ana = new RpmEndAnalyzer();
-    eIter->push_back(ana);
-    ana = new PngEndAnalyzer();
-    eIter->push_back(ana);
-    ana = new PluginEndAnalyzer(&moduleLoader);
-    eIter->push_back(ana);
-
-/*    ana = new PdfEndAnalyzer();
-    eIter->push_back(ana);*/
-    // add a sax analyzer before the text analyzer
-    ana = new SaxEndAnalyzer();
-    eIter->push_back(ana);
-    ana = new HelperEndAnalyzer();
-    eIter->push_back(ana);
-    // add a text analyzer to the end of the queue
-    ana = new TextEndAnalyzer();
-    eIter->push_back(ana);
+    std::vector<StreamEndAnalyzerFactory*>::iterator ea;
+    for (ea = endfactories.begin(); ea != endfactories.end(); ++ea) {
+        eIter->push_back((*ea)->newInstance());
+    }
 }
 char
-StreamIndexer::analyze(const std::string &path, time_t mtime,
-        InputStream *input, uint depth) {
-    static int count = 1;
+StreamIndexer::analyze(Indexable& idx, jstreams::StreamBase<char>* input) {
+//    static int count = 1;
 //    if (++count % 1000 == 0) {
 //        fprintf(stderr, "file #%i: %s\n", count, path.c_str());
 //    }
     //printf("depth #%i: %s\n", depth, path.c_str());
-    Indexable idx(path, mtime, writer, depth);
-   
+
     // retrieve or construct the through analyzers and end analyzers
     std::vector<std::vector<StreamThroughAnalyzer*> >::iterator tIter;
     std::vector<std::vector<StreamEndAnalyzer*> >::iterator eIter;
-    while (through.size() < depth+1) {
+    while ((int)through.size() <= idx.getDepth()) {
         addThroughAnalyzers();
         addEndAnalyzers();
     }
-    tIter = through.begin() + depth;
-    eIter = end.begin() + depth;
+    tIter = through.begin() + idx.getDepth();
+    eIter = end.begin() + idx.getDepth();
 
     // insert the through analyzers
     std::vector<StreamThroughAnalyzer*>::iterator ts;
@@ -168,7 +213,7 @@ StreamIndexer::analyze(const std::string &path, time_t mtime,
     bool finished = false;
     int32_t headersize = 1024;
     const char* header;
-    headersize = input->read(header, headersize, 0);
+    headersize = input->read(header, headersize, headersize);
     if (input->reset(0) != 0) {
         fprintf(stderr, "resetting is impossible!! pos: %lli status: %i\n",
             input->getPosition(), input->getStatus());
@@ -178,29 +223,29 @@ StreamIndexer::analyze(const std::string &path, time_t mtime,
     while (!finished && es != size) {
         StreamEndAnalyzer* sea = (*eIter)[es];
         if (sea->checkHeader(header, headersize)) {
-            char ar = sea->analyze(path, input, depth+1, this, &idx);
+            char ar = sea->analyze(idx, input);
             if (ar) {
                 int64_t pos = input->reset(0);
                 if (pos != 0) { // could not reset
                     fprintf(stderr, "could not reset stream of %s from pos "
-                        "%lli to 0 after reading with %s: %s\n", path.c_str(),
-                        input->getPosition(), sea->getName(),
-                        sea->getError().c_str());
-                    removeIndexable(depth);
+                        "%lli to 0 after reading with %s: %s\n",
+                        idx.getPath().c_str(), input->getPosition(),
+                        sea->getName(), sea->getError().c_str());
+                    removeIndexable(idx.getDepth());
                     return -2;
                 }
             } else {
                 finished = true;
             }
-            eIter = end.begin() + depth;
+            eIter = end.begin() + idx.getDepth();
         }
         es++;
     }
-    // make sure the entire stream as read
+    // make sure the entire stream is read
     bool ready;
-    tIter = through.begin() + depth;
+    tIter = through.begin() + idx.getDepth();
     do {
-        ready = true;
+        ready = input->getSize() != -1;
         std::vector<StreamThroughAnalyzer*>::iterator ts;
         for (ts = tIter->begin(); ready && ts != tIter->end(); ++ts) {
             ready = (*ts)->isReadyWithStream();
@@ -211,12 +256,12 @@ StreamIndexer::analyze(const std::string &path, time_t mtime,
     } while (!ready && input->getStatus() == Ok);
     if (input->getStatus() == Error) {
         fprintf(stderr, "Error: %s\n", input->getError());
-        removeIndexable(depth);
+        removeIndexable(idx.getDepth());
         return -2;
     }
 
     // store the size of the stream
-    {  
+    {
         //tmp scope out tmp mem
         char tmp[100];
         sprintf(tmp, "%lli", input->getSize());
@@ -224,9 +269,12 @@ StreamIndexer::analyze(const std::string &path, time_t mtime,
     }
 
     // remove references to the indexable before it goes out of scope
-    removeIndexable(depth);
+    removeIndexable(idx.getDepth());
     return 0;
 }
+/**
+ * Remove references to the indexable before it goes out of scope.
+ **/
 void
 StreamIndexer::removeIndexable(uint depth) {
     std::vector<std::vector<StreamThroughAnalyzer*> >::iterator tIter;
