@@ -21,12 +21,14 @@
 #define STREAMINDEXER_H
 
 #include <vector>
-#include "moduleloader.h"
+#include "analyzerloader.h"
 
 namespace jstreams {
 class StreamEndAnalyzer;
 class StreamThroughAnalyzer;
 class IndexWriter;
+class Indexable;
+class IndexerConfiguration;
 template <class T> class StreamBase;
 /**
  * The class StreamIndexer extracts information from files or character
@@ -39,27 +41,31 @@ template <class T> class StreamBase;
  * It could filter words from a text or split a stream up in substreams.
  * Especially the last task is important when working with archive streams
  * such as zip or tar files that contain other files.
- *
- * Currently this class is very simple and mainly useful for calculating
- * digests of streams in files in nested archives.
  **/
 class StreamIndexer {
 private:
-    IndexWriter* writer;
+    IndexWriter& writer;
+    IndexerConfiguration& conf;
+    std::vector<jstreams::StreamThroughAnalyzerFactory*> throughfactories;
+    std::vector<jstreams::StreamEndAnalyzerFactory*> endfactories;
     std::vector<std::vector<jstreams::StreamEndAnalyzer*> > end;
     std::vector<std::vector<jstreams::StreamThroughAnalyzer*> > through;
 
-    ModuleLoader moduleLoader;
+    AnalyzerLoader moduleLoader;
+    void initializeThroughFactories();
+    void initializeEndFactories();
+    void addFactory(StreamThroughAnalyzerFactory* f);
+    void addFactory(StreamEndAnalyzerFactory* f);
     void addThroughAnalyzers();
     void addEndAnalyzers();
     void removeIndexable(uint depth);
 public:
-    explicit StreamIndexer(IndexWriter *w);
+    StreamIndexer(IndexWriter& w, IndexerConfiguration& conf);
     ~StreamIndexer();
-    char indexFile(const char *filepath);
+    char indexFile(const char *filepath, IndexerConfiguration* ic=0);
     char indexFile(const std::string& filepath);
-    char analyze(const std::string &path, time_t mtime,
-        jstreams::StreamBase<char> *input, uint depth);
+    char analyze(Indexable& idx, jstreams::StreamBase<char> *input);
+    IndexerConfiguration& getConfiguration() const { return conf; }
 };
 }
 
