@@ -25,11 +25,21 @@
 class TarEndAnalyzer : public jstreams::StreamEndAnalyzer {
 public:
     bool checkHeader(const char* header, int32_t headersize) const;
-    char analyze(std::string filename, jstreams::InputStream *in, int depth,
-        jstreams::StreamIndexer *indexer, jstreams::Indexable*);
-    static char staticAnalyze(std::string filename, jstreams::InputStream *in,
-        int depth, jstreams::StreamIndexer *indexer, jstreams::Indexable*);
+    char analyze(jstreams::Indexable& idx, jstreams::InputStream* in);
+    static char staticAnalyze(jstreams::Indexable& idx,
+        jstreams::InputStream* in);
     const char* getName() const { return "TarEndAnalyzer"; }
 };
 
+class TarEndAnalyzerFactory : public jstreams::StreamEndAnalyzerFactory {
+public:
+    const char* getName() const {
+        return "TarEndAnalyzer";
+    }
+    jstreams::StreamEndAnalyzer* newInstance() const {
+        return new TarEndAnalyzer();
+    }
+    bool analyzesSubStreams() const { return true; }
+};
+
 #endif
