@@ -25,9 +25,18 @@
 class TextEndAnalyzer : public jstreams::StreamEndAnalyzer {
 public:
     bool checkHeader(const char* header, int32_t headersize) const;
-    char analyze(std::string filename, jstreams::InputStream *in, int depth,
-        jstreams::StreamIndexer *indexer, jstreams::Indexable*);
+    char analyze(jstreams::Indexable& idx, jstreams::InputStream* in);
     const char* getName() const { return "TextEndAnalyzer"; }
 };
 
+class TextEndAnalyzerFactory : public jstreams::StreamEndAnalyzerFactory {
+public:
+    const char* getName() const {
+        return "TextEndAnalyzer";
+    }
+    jstreams::StreamEndAnalyzer* newInstance() const {
+        return new TextEndAnalyzer();
+    }
+};
+
 #endif
