@@ -19,29 +19,30 @@
  */
 #define STRIGI_IMPORT_API //todo: could also define this in cmake...
 #include "jstreamsconfig.h"
-#include "strigi_plugins.h"
 
 #include "mimetypethroughanalyzer.h"
-#include "indexwriter.h"
+#include "indexable.h"
 using namespace std;
+using namespace jstreams;
 
 MimeTypeThroughAnalyzer::MimeTypeThroughAnalyzer() {
     magic = magic_open(MAGIC_MIME);
-    if ( magic_load(magic, 0) == -1 )
-		if ( magic_load(magic, "magic") == -1 )
-				fprintf(stderr, "magic_load: %s\n",magic_error(magic));
-
+    if (magic_load(magic, 0) == -1 && magic_load(magic, "magic") == -1) {
+        fprintf(stderr, "magic_load: %s\n",magic_error(magic));
+    }
 }
 MimeTypeThroughAnalyzer::~MimeTypeThroughAnalyzer() {
     magic_close(magic);
 }
-jstreams::InputStream *
-MimeTypeThroughAnalyzer::connectInputStream(jstreams::InputStream *in) {
+::InputStream *
+MimeTypeThroughAnalyzer::connectInputStream(::InputStream *in) {
     // determine the mimetype
     const char* mime;
     int64_t pos = in->getPosition();
     // min == 1 and max == 0 means: 'use whatever buffer size you have already
-    int32_t n = in->read(mime, 1, 0);
+    // we set max = 1024, because otherwise the stream will fill its entire
+    // buffer which can be quite expensive
+    int32_t n = in->read(mime, 1, 1024);
     in->reset(pos);
     if (n >= 0) {
         mime = magic_buffer(magic, mime, n);
@@ -63,7 +64,26 @@ MimeTypeThroughAnalyzer::isReadyWithStream() {
     return true;
 }
 
-//define all the available analyzers in this plugin
-STRIGI_THROUGH_PLUGINS_START
-STRIGI_THROUGH_PLUGINS_REGISTER(MimeTypeThroughAnalyzer)
-STRIGI_THROUGH_PLUGINS_END
+class MimeTypeThroughAnalyzerFactory
+    : public StreamThroughAnalyzerFactory {
+private:
+    const char* getName() const {
+        return "MimeTypeThroughAnalyzer";
+    }
+    StreamThroughAnalyzer* newInstance() const {
+        return new MimeTypeThroughAnalyzer();
+    }
+};
+
+class Factory : public AnalyzerFactoryFactory {
+public:
+    list<StreamThroughAnalyzerFactory*>
+    getStreamThroughAnalyzerFactories() const {
+        list<StreamThroughAnalyzerFactory*> af;
+        af.push_back(new MimeTypeThroughAnalyzerFactory());
+        return af;
+    }
+};
+
+STRIGI_ANALYZER_FACTORY(Factory)
+
