@@ -21,10 +21,12 @@
 #define MIMETYPETHROUGHANALYZER_H
 
 #include "streamthroughanalyzer.h"
+#include "analyzerplugin.h"
 extern "C" {
     #include <magic.h>
 }
-class STRIGI_PLUGIN_API MimeTypeThroughAnalyzer : public jstreams::StreamThroughAnalyzer {
+class STRIGI_PLUGIN_API MimeTypeThroughAnalyzer
+        : public jstreams::StreamThroughAnalyzer {
 private:
     magic_t magic;
     jstreams::Indexable* idx;
