@@ -19,11 +19,14 @@
  */
 #define STRIGI_IMPORT_API //todo: could also define this in cmake...
 #include <jstreamsconfig.h>
-#include <strigi_plugins.h>
-#include <indexwriter.h>
+#include <streamthroughanalyzer.h>
+#include <analyzerplugin.h>
+#include <indexable.h>
 #include <sys/types.h>
 #include <attr/xattr.h>
 #include <errno.h>
+using namespace jstreams;
+using namespace std;
 
 class XattrAnalyzer : public jstreams::StreamThroughAnalyzer {
 private:
@@ -54,8 +57,6 @@ public:
     bool isReadyWithStream() { return true; }
 };
 
-//REGISTER_THROUGHANALYZER(XattrAnalyzer)
-
 jstreams::InputStream *
 XattrAnalyzer::connectInputStream(jstreams::InputStream *in) {
     if (idx->getDepth() != 0) return in;
@@ -66,7 +67,7 @@ XattrAnalyzer::connectInputStream(jstreams::InputStream *in) {
             namesize *= 2;
             namebuffer = (char*)realloc(namebuffer, namesize);
         }
-        s = llistxattr(idx->getName().c_str(), namebuffer, namesize);
+        s = llistxattr(idx->getPath().c_str(), namebuffer, namesize);
     } while (s == -1 && errno == ERANGE && namesize < maxnamesize);
     if (s == -1) return in;
 
@@ -97,7 +98,7 @@ XattrAnalyzer::retrieveAttribute(const char* name) {
             valsize *= 2;
             valbuffer = (char*)realloc(valbuffer, valsize);
         }
-        s = lgetxattr(idx->getName().c_str(), name, valbuffer, valsize-1);
+        s = lgetxattr(idx->getPath().c_str(), name, valbuffer, valsize-1);
     } while (s == -1 && errno == ERANGE && valsize < maxvalsize);
     if (s == -1) return 0;
     valbuffer[s] = '\0';
@@ -105,6 +106,24 @@ XattrAnalyzer::retrieveAttribute(const char* name) {
 }
 
 //define all the available analyzers in this plugin
-STRIGI_THROUGH_PLUGINS_START
-STRIGI_THROUGH_PLUGINS_REGISTER(XattrAnalyzer)
-STRIGI_THROUGH_PLUGINS_END
+class XattrThroughAnalyzerFactory : public StreamThroughAnalyzerFactory {
+private:
+    const char* getName() const {
+        return "XattrThroughAnalyzer";
+    }
+    StreamThroughAnalyzer* newInstance() const {
+        return new XattrAnalyzer();
+    }
+};
+
+class Factory : public AnalyzerFactoryFactory {
+public:
+    list<StreamThroughAnalyzerFactory*>
+    getStreamThroughAnalyzerFactories() const {
+        list<StreamThroughAnalyzerFactory*> af;
+        af.push_back(new XattrThroughAnalyzerFactory());
+        return af;
+    }
+};
+
+STRIGI_ANALYZER_FACTORY(Factory)
