@@ -32,7 +32,7 @@ private:
     bool finishedWritingToBuffer;
     InputStreamBuffer<T> buffer;
 
-    void writeToBuffer(int32_t minsize);
+    void writeToBuffer(int32_t minsize, int32_t maxsize);
     int32_t read_(const T*& start, int32_t min, int32_t max);
 protected:
     /**
@@ -46,6 +46,9 @@ protected:
     virtual int32_t fillBuffer(T* start, int32_t space) = 0;
     // this function might be useful if you want to reuse a bufferedstream
     void resetBuffer() {printf("implement 'resetBuffer'\n");}
+    void setMinBufSize(int32_t s) {
+        buffer.makeSpace(s);
+    }
     BufferedInputStream<T>();
 public:
     int32_t read(const T*& start, int32_t min, int32_t max);
@@ -60,12 +63,15 @@ BufferedInputStream<T>::BufferedInputStream() {
 
 template <class T>
 void
-BufferedInputStream<T>::writeToBuffer(int32_t ntoread) {
+BufferedInputStream<T>::writeToBuffer(int32_t ntoread, int32_t maxread) {
     int32_t missing = ntoread - buffer.avail;
     int32_t nwritten = 0;
     while (missing > 0 && nwritten >= 0) {
         int32_t space;
         space = buffer.makeSpace(missing);
+        if (maxread >= ntoread && space > maxread) {
+             space = maxread;
+        }
         T* start = buffer.readPos + buffer.avail;
         nwritten = fillBuffer(start, space);
         assert(StreamBase<T>::status != Eof);
@@ -87,26 +93,26 @@ BufferedInputStream<T>::read(const T*& start, int32_t min, int32_t max) {
     // do we need to read data into the buffer?
     if (!finishedWritingToBuffer && min > buffer.avail) {
         // do we have enough space in the buffer?
-        writeToBuffer(min);
+        writeToBuffer(min, max);
         if (StreamBase<T>::status == Error) return -2;
     }
 
     int32_t nread = buffer.read(start, max);
 
-    BufferedInputStream<T>::position += nread;
-    if (BufferedInputStream<T>::position > BufferedInputStream<T>::size
-        && BufferedInputStream<T>::size > 0) {
+    StreamBase<T>::position += nread;
+    if (StreamBase<T>::position > StreamBase<T>::size
+        && StreamBase<T>::size > 0) {
         // error: we read more than was specified in size
         // this is an error because all dependent code might have been labouring
         // under a misapprehension
-        BufferedInputStream<T>::status = Error;
-        BufferedInputStream<T>::error = "Stream is longer than specified.";
+        StreamBase<T>::status = Error;
+        StreamBase<T>::error = "Stream is longer than specified.";
         nread = -2;
-    } else if (BufferedInputStream<T>::status == Ok && buffer.avail == 0
+    } else if (StreamBase<T>::status == Ok && buffer.avail == 0
             && finishedWritingToBuffer) {
-        BufferedInputStream<T>::status = Eof;
-        if (BufferedInputStream<T>::size == -1) {
-            BufferedInputStream<T>::size = BufferedInputStream<T>::position;
+        StreamBase<T>::status = Eof;
+        if (StreamBase<T>::size == -1) {
+            StreamBase<T>::size = StreamBase<T>::position;
         }
         // save one call to read() by already returning -1 if no data is there
         if (nread == 0) nread = -1;
@@ -119,10 +125,10 @@ BufferedInputStream<T>::reset(int64_t newpos) {
     assert(newpos >= 0);
     if (StreamBase<T>::status == Error) return -2;
     // check to see if we have this position
-    int64_t d = BufferedInputStream<T>::position - newpos;
+    int64_t d = StreamBase<T>::position - newpos;
     if (buffer.readPos - d >= buffer.start && -d < buffer.avail) {
-        BufferedInputStream<T>::position -= d;
-        buffer.avail += d;
+        StreamBase<T>::position -= d;
+        buffer.avail += (int32_t)d;
         buffer.readPos -= d;
         StreamBase<T>::status = Ok;
     }
