@@ -30,7 +30,7 @@ class FileReader : public StreamBase<wchar_t> {
     FileInputStream* input;
     InputStreamReader* reader;
 public:
-    FileReader(const char* fname, const char* encoding_scheme=NULL,
+    explicit FileReader(const char* fname, const char* encoding_scheme=NULL,
         const int32_t cachelen = 13,
         const int32_t cachebuff = 14 );
     ~FileReader();
