@@ -55,7 +55,7 @@ MailInputStream::checkHeader(const char* data, int32_t datasize) {
     bool reqheader = checkHeaderKey(data, datasize);
     char prevc = 0;
     while (pos < datasize) {
-        char c = data[pos++];
+        unsigned char c = data[pos++];
         if (slashr) {
             slashr = false;
             if (c == '\n') {
@@ -261,12 +261,82 @@ MailInputStream::scanBody() {
             break;
         }
     }
-
-//    const char* bend = strchr(bstart+1, '"');
- //   string boundary(bstart+1, bend-bstart-2);
-//    printf("%s\n", contenttype.c_str());
-//    printf("%s\n", boundary.c_str());
-//    printf("%s %i\n", boundary.c_str(), n);
+}
+char
+decodeHex(char h) {
+    if (h >= 'A' && h <= 'F') return 10+h-'A';
+    if (h >= 'a' && h <= 'f') return 10+h-'a';
+    return h - '0';
+}
+string
+decodeQuotedPrintable(const char* v, int32_t len) {
+    string decoded;
+    decoded.reserve(len);
+    const char* pos = v;
+    const char* end = v + len;
+    char c;
+    while (v < end) {
+        if (*v == '=' && end - v > 2 && isxdigit(v[1]) && isxdigit(v[2])) {
+            decoded.append(pos, v - pos);
+            c = decodeHex(v[1])*16 + decodeHex(v[2]);
+            decoded.append(&c, 1);
+            pos = v = v + 3;
+        } else if (*v == '_') {
+            decoded.append(pos, v - pos);
+            decoded.append(" ");
+            v++;
+        } else {
+            v++;
+        }
+    }
+    if (pos < end) {
+        decoded.append(pos, end-pos);
+    }
+    return decoded;
+}
+/**
+ * This function can decode a mail header if it contains utf8 encoded in base64.
+ **/
+string
+getDecodedHeaderValue(const char* v, int32_t len) {
+    string decoded;
+    decoded.reserve(len*2);
+    const char* s = v;
+    const char* p = v;
+    const char* e = s + len;
+    while (s < e) {
+        if (*s == '=' && e-s >= 12 && strncasecmp("?utf-8?", s+1, 7) == 0) {
+            if (strncasecmp("b?", s+8, 2) == 0) {
+                const char* ec = s + 10;
+                while (ec < e && *ec != '?') ec += 4;
+                if (ec < e - 1) {
+                    decoded.append(p, s-p);
+                    decoded.append(Base64InputStream::decode(s+10, ec-10-s));
+                    s = p = ec + 2;
+                } else {
+                    s++;
+                }
+            } else if (strncasecmp("q?", s+8, 2) == 0) {
+                const char* ec = s + 10;
+                while (ec < e && *ec != '?') ++ec;
+                if (ec < e -1) {
+                    decoded.append(p, s-p);
+                    decoded.append(decodeQuotedPrintable(s+10, ec-10-s));
+                    s = p = ec + 2;
+                } else {
+                    s++;
+                }
+            } else {
+                s++;
+            }
+        } else {
+            s++;
+        }
+    }
+    if (p < e) {
+        decoded.append(p, e-p);
+    }
+    return decoded;
 }
 void
 MailInputStream::handleHeaderLine() {
@@ -284,7 +354,7 @@ MailInputStream::handleHeaderLine() {
     } else if (strncasecmp(linestart, subject, 8) == 0) {
         int32_t offset = 8;
         while (offset < len && isspace(linestart[offset])) offset++;
-        this->subject = std::string(linestart+offset, len-offset);
+        this->subject = getDecodedHeaderValue(linestart+offset, len-offset);
         lastHeader = &this->subject;
     } else if (strncasecmp(linestart, contenttype, 13) == 0) {
         int32_t offset = 13;
@@ -309,7 +379,7 @@ MailInputStream::checkHeaderLine() const {
         while (*colpos != ':' && ++colpos != lineend) {}
         validheader = colpos != lineend || isblank(*linestart);
     }
-    return validheader;   
+    return validheader;
 }
 // return true if we are at the start of a base64 encoded block
 void
