@@ -19,6 +19,8 @@
  */
 #include "jstreamsconfig.h"
 #include "processinputstream.h"
+#include <errno.h>
+#include <unistd.h>
 using namespace jstreams;
 using namespace std;
 
@@ -26,6 +28,8 @@ using namespace std;
 #if defined(__APPLE__)
 # include <crt_externs.h>
 # define environ (*_NSGetEnviron())
+#else
+extern char **environ;
 #endif
 
 ProcessInputStream::ProcessInputStream(const vector<string>& a,
@@ -33,10 +37,11 @@ ProcessInputStream::ProcessInputStream(const vector<string>& a,
     this->input = input;
     fdin = fdout = pid = -1;
 
+    // create an arguments structure
     char** ar = new char*[a.size()+1];
-    for (uint i=0; i<a.size(); ++i) {
-        ar[i] = new char[a[i].length()+1];
-        strcpy(ar[i], a[i].c_str());
+    for (uint i = 0; i < a.size(); ++i) {
+        ar[i] = (char*)malloc(a[i].length()+1);
+        memcpy(ar[i], a[i].c_str(), a[i].length()+1);
     }
     ar[a.size()] = 0;
     args = ar;
@@ -56,7 +61,7 @@ ProcessInputStream::~ProcessInputStream() {
     }
     const char* const* p = args;
     while (*p) {
-        delete [] *p++;
+        free((void*)*p++);
     }
     delete [] args;
 }
@@ -67,26 +72,25 @@ ProcessInputStream::writeToPipe() {
     const char* b;
     int32_t n = input->read(b, 1, 0);
     if (n <= 0 || input->getStatus() == Eof) {
-        input = 0;
-        if (n < 0) {
+        if (input->getStatus() == Error) {
             status = Error;
+            error = input->getError();
             n = 0;
         }
-    }
-
-    // write into the pipe
-    int32_t m = write(fdin, b, n);
-    if (m < 0) {
-        status = Error;
+        // close the pipe if no more output is available
         input = 0;
-    } else if (m != n) {
-        input->reset(pos+n);
-    }
-
-    // close the pipe if no more output is available
-    if (!input) {
         close(fdin);
         fdin = -1;
+    } else {
+        // write into the pipe
+        int32_t m = write(fdin, b, n);
+        if (m < 0) {
+            error = strerror(errno);
+            status = Error;
+            input = 0;
+        } else if (m != n) {
+            input->reset(pos+n);
+        }
     }
 }
 int32_t
@@ -97,6 +101,7 @@ ProcessInputStream::fillBuffer(char* start, int32_t space) {
     }
     ssize_t n = ::read(fdout, start, space);
     if (n < 0) {
+        error = strerror(errno);
         status = Error;
     }
     if (n <= 0) {
@@ -106,7 +111,6 @@ ProcessInputStream::fillBuffer(char* start, int32_t space) {
     }
     return n;
 }
-#include <errno.h>
 void
 ProcessInputStream::runCmd() {
     int p[2];
