@@ -109,6 +109,10 @@ SubInputStream::skip(int64_t ntoskip) {
         position += skipped;
         if (position == size) {
             status = Eof;
+        } else if (skipped <= 0) {
+            status = Error;
+            error = "Premature end of stream\n";
+            skipped = -2;
         }
     }
     return skipped;
