@@ -25,7 +25,6 @@
 #include "xmlindexwriter.h"
 
 class FileLister;
-class FilterManager;
 
 class Indexer {
 private:
@@ -34,12 +33,12 @@ private:
     XmlIndexWriter writer;
     jstreams::StreamIndexer m_indexer;
 
-    static bool addFileCallback(const char* fullpath, uint dirlen,
+    static void addFileCallback(const char* fullpath, uint dirlen,
         uint len, time_t mtime);
     static Indexer *workingIndexer;
     void doFile(const char* filepath);
 public:
-    Indexer(FilterManager* filtermanager, std::ostream& out);
+    Indexer(std::ostream& out, jstreams::IndexerConfiguration& );
     ~Indexer();
     void index(const char *dir);
 };
